pub struct Blob(pub Vec<u8>);Expand description
Opaque blob of bytes that should be passed through without interpretation.
Returned by functions whose response type is generic (e.g. X).
Tuple Fields
0: Vec<u8>Trait Implementations
impl StructuralPartialEq for Blob