pub struct SentCodeTypeSetUpEmailRequired {
pub apple_signin_allowed: bool,
pub google_signin_allowed: bool,
}Expand description
auth.sentCodeTypeSetUpEmailRequired
Generated from:
auth.sentCodeTypeSetUpEmailRequired#a5491dea flags:# apple_signin_allowed:flags.0?true google_signin_allowed:flags.1?true = auth.SentCodeTypeFields
apple_signin_allowed: boolgoogle_signin_allowed: boolTrait Implementations
Sourceimpl Clone for SentCodeTypeSetUpEmailRequired
impl Clone for SentCodeTypeSetUpEmailRequired
Sourcefn clone(&self) -> SentCodeTypeSetUpEmailRequired
fn clone(&self) -> SentCodeTypeSetUpEmailRequired
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for SentCodeTypeSetUpEmailRequired
impl Deserializable for SentCodeTypeSetUpEmailRequired
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<SentCodeTypeSetUpEmailRequired> for SentCodeType
impl From<SentCodeTypeSetUpEmailRequired> for SentCodeType
Sourcefn from(x: SentCodeTypeSetUpEmailRequired) -> Self
fn from(x: SentCodeTypeSetUpEmailRequired) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for SentCodeTypeSetUpEmailRequired
impl Identifiable for SentCodeTypeSetUpEmailRequired
Sourceconst CONSTRUCTOR_ID: u32 = 0xa5491dea
const CONSTRUCTOR_ID: u32 = 0xa5491dea
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for SentCodeTypeSetUpEmailRequired
impl PartialEq for SentCodeTypeSetUpEmailRequired
Sourcefn eq(&self, other: &SentCodeTypeSetUpEmailRequired) -> bool
fn eq(&self, other: &SentCodeTypeSetUpEmailRequired) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<SentCodeType> for SentCodeTypeSetUpEmailRequired
impl TryFrom<SentCodeType> for SentCodeTypeSetUpEmailRequired
Sourcetype Error = SentCodeType
type Error = SentCodeType
The type returned in the event of a conversion error.
impl StructuralPartialEq for SentCodeTypeSetUpEmailRequired