pub struct StickerSetInstallResultArchive {
pub sets: Vec<StickerSetCovered>,
}Expand description
messages.stickerSetInstallResultArchive
Generated from:
messages.stickerSetInstallResultArchive#35e410a8 sets:Vector<StickerSetCovered> = messages.StickerSetInstallResultFields
sets: Vec<StickerSetCovered>Trait Implementations
Sourceimpl Clone for StickerSetInstallResultArchive
impl Clone for StickerSetInstallResultArchive
Sourcefn clone(&self) -> StickerSetInstallResultArchive
fn clone(&self) -> StickerSetInstallResultArchive
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for StickerSetInstallResultArchive
impl Deserializable for StickerSetInstallResultArchive
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<StickerSetInstallResultArchive> for StickerSetInstallResult
impl From<StickerSetInstallResultArchive> for StickerSetInstallResult
Sourcefn from(x: StickerSetInstallResultArchive) -> Self
fn from(x: StickerSetInstallResultArchive) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for StickerSetInstallResultArchive
impl Identifiable for StickerSetInstallResultArchive
Sourceconst CONSTRUCTOR_ID: u32 = 0x35e410a8
const CONSTRUCTOR_ID: u32 = 0x35e410a8
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for StickerSetInstallResultArchive
impl PartialEq for StickerSetInstallResultArchive
Sourcefn eq(&self, other: &StickerSetInstallResultArchive) -> bool
fn eq(&self, other: &StickerSetInstallResultArchive) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<StickerSetInstallResult> for StickerSetInstallResultArchive
impl TryFrom<StickerSetInstallResult> for StickerSetInstallResultArchive
Sourcetype Error = StickerSetInstallResult
type Error = StickerSetInstallResult
The type returned in the event of a conversion error.
impl StructuralPartialEq for StickerSetInstallResultArchive