pub struct BotInlineMessageMediaContact {
pub phone_number: String,
pub first_name: String,
pub last_name: String,
pub vcard: String,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Generated from:
botInlineMessageMediaContact#18d1cdc2 flags:# phone_number:string first_name:string last_name:string vcard:string reply_markup:flags.2?ReplyMarkup = BotInlineMessageFields
phone_number: Stringfirst_name: Stringlast_name: Stringvcard: Stringreply_markup: Option<ReplyMarkup>Trait Implementations
Sourceimpl Clone for BotInlineMessageMediaContact
impl Clone for BotInlineMessageMediaContact
Sourcefn clone(&self) -> BotInlineMessageMediaContact
fn clone(&self) -> BotInlineMessageMediaContact
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BotInlineMessageMediaContact
impl Debug for BotInlineMessageMediaContact
Sourceimpl Deserializable for BotInlineMessageMediaContact
impl Deserializable for BotInlineMessageMediaContact
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<BotInlineMessageMediaContact> for BotInlineMessage
impl From<BotInlineMessageMediaContact> for BotInlineMessage
Sourcefn from(x: BotInlineMessageMediaContact) -> Self
fn from(x: BotInlineMessageMediaContact) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for BotInlineMessageMediaContact
impl Identifiable for BotInlineMessageMediaContact
Sourceconst CONSTRUCTOR_ID: u32 = 0x18d1cdc2
const CONSTRUCTOR_ID: u32 = 0x18d1cdc2
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for BotInlineMessageMediaContact
impl PartialEq for BotInlineMessageMediaContact
Sourcefn eq(&self, other: &BotInlineMessageMediaContact) -> bool
fn eq(&self, other: &BotInlineMessageMediaContact) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<BotInlineMessage> for BotInlineMessageMediaContact
impl TryFrom<BotInlineMessage> for BotInlineMessageMediaContact
Sourcetype Error = BotInlineMessage
type Error = BotInlineMessage
The type returned in the event of a conversion error.
impl StructuralPartialEq for BotInlineMessageMediaContact