pub struct BotInlineMessageMediaWebPage {
pub invert_media: bool,
pub force_large_media: bool,
pub force_small_media: bool,
pub manual: bool,
pub safe: bool,
pub message: String,
pub entities: Option<Vec<MessageEntity>>,
pub url: String,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Generated from:
botInlineMessageMediaWebPage#809ad9a6 flags:# invert_media:flags.3?true force_large_media:flags.4?true force_small_media:flags.5?true manual:flags.7?true safe:flags.8?true message:string entities:flags.1?Vector<MessageEntity> url:string reply_markup:flags.2?ReplyMarkup = BotInlineMessageFields
invert_media: boolforce_large_media: boolforce_small_media: boolmanual: boolsafe: boolmessage: Stringentities: Option<Vec<MessageEntity>>url: Stringreply_markup: Option<ReplyMarkup>Trait Implementations
Sourceimpl Clone for BotInlineMessageMediaWebPage
impl Clone for BotInlineMessageMediaWebPage
Sourcefn clone(&self) -> BotInlineMessageMediaWebPage
fn clone(&self) -> BotInlineMessageMediaWebPage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BotInlineMessageMediaWebPage
impl Debug for BotInlineMessageMediaWebPage
Sourceimpl Deserializable for BotInlineMessageMediaWebPage
impl Deserializable for BotInlineMessageMediaWebPage
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<BotInlineMessageMediaWebPage> for BotInlineMessage
impl From<BotInlineMessageMediaWebPage> for BotInlineMessage
Sourcefn from(x: BotInlineMessageMediaWebPage) -> Self
fn from(x: BotInlineMessageMediaWebPage) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for BotInlineMessageMediaWebPage
impl Identifiable for BotInlineMessageMediaWebPage
Sourceconst CONSTRUCTOR_ID: u32 = 0x809ad9a6
const CONSTRUCTOR_ID: u32 = 0x809ad9a6
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for BotInlineMessageMediaWebPage
impl PartialEq for BotInlineMessageMediaWebPage
Sourcefn eq(&self, other: &BotInlineMessageMediaWebPage) -> bool
fn eq(&self, other: &BotInlineMessageMediaWebPage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<BotInlineMessage> for BotInlineMessageMediaWebPage
impl TryFrom<BotInlineMessage> for BotInlineMessageMediaWebPage
Sourcetype Error = BotInlineMessage
type Error = BotInlineMessage
The type returned in the event of a conversion error.
impl StructuralPartialEq for BotInlineMessageMediaWebPage