pub struct ChannelAdminLogEventActionChangeAbout {
pub prev_value: String,
pub new_value: String,
}Expand description
channelAdminLogEventActionChangeAbout
Generated from:
channelAdminLogEventActionChangeAbout#55188a2e prev_value:string new_value:string = ChannelAdminLogEventActionFields
prev_value: Stringnew_value: StringTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeAbout
impl Clone for ChannelAdminLogEventActionChangeAbout
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeAbout
fn clone(&self) -> ChannelAdminLogEventActionChangeAbout
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeAbout
impl Deserializable for ChannelAdminLogEventActionChangeAbout
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeAbout> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeAbout> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeAbout) -> Self
fn from(x: ChannelAdminLogEventActionChangeAbout) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeAbout
impl Identifiable for ChannelAdminLogEventActionChangeAbout
Sourceconst CONSTRUCTOR_ID: u32 = 0x55188a2e
const CONSTRUCTOR_ID: u32 = 0x55188a2e
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeAbout
impl PartialEq for ChannelAdminLogEventActionChangeAbout
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeAbout) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeAbout) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeAbout
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeAbout
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeAbout