pub struct ChannelAdminLogEventActionChangeAvailableReactions {
pub prev_value: ChatReactions,
pub new_value: ChatReactions,
}Expand description
channelAdminLogEventActionChangeAvailableReactions
Generated from:
channelAdminLogEventActionChangeAvailableReactions#be4e0ef8 prev_value:ChatReactions new_value:ChatReactions = ChannelAdminLogEventActionFields
prev_value: ChatReactionsnew_value: ChatReactionsTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeAvailableReactions
impl Clone for ChannelAdminLogEventActionChangeAvailableReactions
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeAvailableReactions
fn clone(&self) -> ChannelAdminLogEventActionChangeAvailableReactions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeAvailableReactions
impl Deserializable for ChannelAdminLogEventActionChangeAvailableReactions
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeAvailableReactions> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeAvailableReactions> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeAvailableReactions) -> Self
fn from(x: ChannelAdminLogEventActionChangeAvailableReactions) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeAvailableReactions
impl Identifiable for ChannelAdminLogEventActionChangeAvailableReactions
Sourceconst CONSTRUCTOR_ID: u32 = 0xbe4e0ef8
const CONSTRUCTOR_ID: u32 = 0xbe4e0ef8
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeAvailableReactions
impl PartialEq for ChannelAdminLogEventActionChangeAvailableReactions
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeAvailableReactions) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeAvailableReactions) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeAvailableReactions
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeAvailableReactions
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeAvailableReactions