pub struct ChannelAdminLogEventActionChangeEmojiStickerSet {
pub prev_stickerset: InputStickerSet,
pub new_stickerset: InputStickerSet,
}Expand description
channelAdminLogEventActionChangeEmojiStickerSet
Generated from:
channelAdminLogEventActionChangeEmojiStickerSet#46d840ab prev_stickerset:InputStickerSet new_stickerset:InputStickerSet = ChannelAdminLogEventActionFields
prev_stickerset: InputStickerSetnew_stickerset: InputStickerSetTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeEmojiStickerSet
impl Clone for ChannelAdminLogEventActionChangeEmojiStickerSet
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeEmojiStickerSet
fn clone(&self) -> ChannelAdminLogEventActionChangeEmojiStickerSet
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeEmojiStickerSet
impl Deserializable for ChannelAdminLogEventActionChangeEmojiStickerSet
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeEmojiStickerSet> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeEmojiStickerSet> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeEmojiStickerSet) -> Self
fn from(x: ChannelAdminLogEventActionChangeEmojiStickerSet) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeEmojiStickerSet
impl Identifiable for ChannelAdminLogEventActionChangeEmojiStickerSet
Sourceconst CONSTRUCTOR_ID: u32 = 0x46d840ab
const CONSTRUCTOR_ID: u32 = 0x46d840ab
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeEmojiStickerSet
impl PartialEq for ChannelAdminLogEventActionChangeEmojiStickerSet
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeEmojiStickerSet) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeEmojiStickerSet) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeEmojiStickerSet
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeEmojiStickerSet
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeEmojiStickerSet