pub struct ChannelAdminLogEventActionChangeHistoryTtl {
pub prev_value: i32,
pub new_value: i32,
}Expand description
channelAdminLogEventActionChangeHistoryTTL
Generated from:
channelAdminLogEventActionChangeHistoryTTL#6e941a38 prev_value:int new_value:int = ChannelAdminLogEventActionFields
prev_value: i32new_value: i32Trait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeHistoryTtl
impl Clone for ChannelAdminLogEventActionChangeHistoryTtl
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeHistoryTtl
fn clone(&self) -> ChannelAdminLogEventActionChangeHistoryTtl
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeHistoryTtl
impl Deserializable for ChannelAdminLogEventActionChangeHistoryTtl
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeHistoryTtl> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeHistoryTtl> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeHistoryTtl) -> Self
fn from(x: ChannelAdminLogEventActionChangeHistoryTtl) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeHistoryTtl
impl Identifiable for ChannelAdminLogEventActionChangeHistoryTtl
Sourceconst CONSTRUCTOR_ID: u32 = 0x6e941a38
const CONSTRUCTOR_ID: u32 = 0x6e941a38
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeHistoryTtl
impl PartialEq for ChannelAdminLogEventActionChangeHistoryTtl
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeHistoryTtl) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeHistoryTtl) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeHistoryTtl
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeHistoryTtl
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeHistoryTtl