pub struct ChannelAdminLogEventActionChangeLinkedChat {
pub prev_value: i64,
pub new_value: i64,
}Expand description
channelAdminLogEventActionChangeLinkedChat
Generated from:
channelAdminLogEventActionChangeLinkedChat#50c7ac8 prev_value:long new_value:long = ChannelAdminLogEventActionFields
prev_value: i64new_value: i64Trait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeLinkedChat
impl Clone for ChannelAdminLogEventActionChangeLinkedChat
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeLinkedChat
fn clone(&self) -> ChannelAdminLogEventActionChangeLinkedChat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeLinkedChat
impl Deserializable for ChannelAdminLogEventActionChangeLinkedChat
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeLinkedChat> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeLinkedChat> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeLinkedChat) -> Self
fn from(x: ChannelAdminLogEventActionChangeLinkedChat) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeLinkedChat
impl Identifiable for ChannelAdminLogEventActionChangeLinkedChat
Sourceconst CONSTRUCTOR_ID: u32 = 0x050c7ac8
const CONSTRUCTOR_ID: u32 = 0x050c7ac8
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeLinkedChat
impl PartialEq for ChannelAdminLogEventActionChangeLinkedChat
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeLinkedChat) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeLinkedChat) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeLinkedChat
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeLinkedChat
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeLinkedChat