pub struct ChannelAdminLogEventActionChangeLocation {
pub prev_value: ChannelLocation,
pub new_value: ChannelLocation,
}Expand description
channelAdminLogEventActionChangeLocation
Generated from:
channelAdminLogEventActionChangeLocation#e6b76ae prev_value:ChannelLocation new_value:ChannelLocation = ChannelAdminLogEventActionFields
prev_value: ChannelLocationnew_value: ChannelLocationTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeLocation
impl Clone for ChannelAdminLogEventActionChangeLocation
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeLocation
fn clone(&self) -> ChannelAdminLogEventActionChangeLocation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeLocation
impl Deserializable for ChannelAdminLogEventActionChangeLocation
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeLocation> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeLocation> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeLocation) -> Self
fn from(x: ChannelAdminLogEventActionChangeLocation) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeLocation
impl Identifiable for ChannelAdminLogEventActionChangeLocation
Sourceconst CONSTRUCTOR_ID: u32 = 0x0e6b76ae
const CONSTRUCTOR_ID: u32 = 0x0e6b76ae
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeLocation
impl PartialEq for ChannelAdminLogEventActionChangeLocation
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeLocation) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeLocation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeLocation
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeLocation
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeLocation