pub struct ChannelAdminLogEventActionChangePhoto {
pub prev_photo: Photo,
pub new_photo: Photo,
}Expand description
channelAdminLogEventActionChangePhoto
Generated from:
channelAdminLogEventActionChangePhoto#434bd2af prev_photo:Photo new_photo:Photo = ChannelAdminLogEventActionFields
prev_photo: Photonew_photo: PhotoTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangePhoto
impl Clone for ChannelAdminLogEventActionChangePhoto
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangePhoto
fn clone(&self) -> ChannelAdminLogEventActionChangePhoto
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangePhoto
impl Deserializable for ChannelAdminLogEventActionChangePhoto
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangePhoto> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangePhoto> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangePhoto) -> Self
fn from(x: ChannelAdminLogEventActionChangePhoto) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangePhoto
impl Identifiable for ChannelAdminLogEventActionChangePhoto
Sourceconst CONSTRUCTOR_ID: u32 = 0x434bd2af
const CONSTRUCTOR_ID: u32 = 0x434bd2af
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangePhoto
impl PartialEq for ChannelAdminLogEventActionChangePhoto
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangePhoto) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangePhoto) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangePhoto
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangePhoto
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangePhoto