pub struct ChannelAdminLogEventActionChangeStickerSet {
pub prev_stickerset: InputStickerSet,
pub new_stickerset: InputStickerSet,
}Expand description
channelAdminLogEventActionChangeStickerSet
Generated from:
channelAdminLogEventActionChangeStickerSet#b1c3caa7 prev_stickerset:InputStickerSet new_stickerset:InputStickerSet = ChannelAdminLogEventActionFields
prev_stickerset: InputStickerSetnew_stickerset: InputStickerSetTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeStickerSet
impl Clone for ChannelAdminLogEventActionChangeStickerSet
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeStickerSet
fn clone(&self) -> ChannelAdminLogEventActionChangeStickerSet
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeStickerSet
impl Deserializable for ChannelAdminLogEventActionChangeStickerSet
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeStickerSet> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeStickerSet> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeStickerSet) -> Self
fn from(x: ChannelAdminLogEventActionChangeStickerSet) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeStickerSet
impl Identifiable for ChannelAdminLogEventActionChangeStickerSet
Sourceconst CONSTRUCTOR_ID: u32 = 0xb1c3caa7
const CONSTRUCTOR_ID: u32 = 0xb1c3caa7
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeStickerSet
impl PartialEq for ChannelAdminLogEventActionChangeStickerSet
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeStickerSet) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeStickerSet) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeStickerSet
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeStickerSet
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeStickerSet