pub struct ChannelAdminLogEventActionChangeTitle {
pub prev_value: String,
pub new_value: String,
}Expand description
channelAdminLogEventActionChangeTitle
Generated from:
channelAdminLogEventActionChangeTitle#e6dfb825 prev_value:string new_value:string = ChannelAdminLogEventActionFields
prev_value: Stringnew_value: StringTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeTitle
impl Clone for ChannelAdminLogEventActionChangeTitle
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeTitle
fn clone(&self) -> ChannelAdminLogEventActionChangeTitle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeTitle
impl Deserializable for ChannelAdminLogEventActionChangeTitle
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeTitle> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeTitle> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeTitle) -> Self
fn from(x: ChannelAdminLogEventActionChangeTitle) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeTitle
impl Identifiable for ChannelAdminLogEventActionChangeTitle
Sourceconst CONSTRUCTOR_ID: u32 = 0xe6dfb825
const CONSTRUCTOR_ID: u32 = 0xe6dfb825
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeTitle
impl PartialEq for ChannelAdminLogEventActionChangeTitle
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeTitle) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeTitle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeTitle
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeTitle
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeTitle