pub struct ChannelAdminLogEventActionChangeUsername {
pub prev_value: String,
pub new_value: String,
}Expand description
channelAdminLogEventActionChangeUsername
Generated from:
channelAdminLogEventActionChangeUsername#6a4afc38 prev_value:string new_value:string = ChannelAdminLogEventActionFields
prev_value: Stringnew_value: StringTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeUsername
impl Clone for ChannelAdminLogEventActionChangeUsername
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeUsername
fn clone(&self) -> ChannelAdminLogEventActionChangeUsername
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeUsername
impl Deserializable for ChannelAdminLogEventActionChangeUsername
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeUsername> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeUsername> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeUsername) -> Self
fn from(x: ChannelAdminLogEventActionChangeUsername) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeUsername
impl Identifiable for ChannelAdminLogEventActionChangeUsername
Sourceconst CONSTRUCTOR_ID: u32 = 0x6a4afc38
const CONSTRUCTOR_ID: u32 = 0x6a4afc38
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeUsername
impl PartialEq for ChannelAdminLogEventActionChangeUsername
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeUsername) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeUsername) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeUsername
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeUsername
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeUsername