pub struct ChannelAdminLogEventActionChangeUsernames {
pub prev_value: Vec<String>,
pub new_value: Vec<String>,
}Expand description
channelAdminLogEventActionChangeUsernames
Generated from:
channelAdminLogEventActionChangeUsernames#f04fb3a9 prev_value:Vector<string> new_value:Vector<string> = ChannelAdminLogEventActionFields
prev_value: Vec<String>new_value: Vec<String>Trait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeUsernames
impl Clone for ChannelAdminLogEventActionChangeUsernames
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeUsernames
fn clone(&self) -> ChannelAdminLogEventActionChangeUsernames
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeUsernames
impl Deserializable for ChannelAdminLogEventActionChangeUsernames
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeUsernames> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeUsernames> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeUsernames) -> Self
fn from(x: ChannelAdminLogEventActionChangeUsernames) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeUsernames
impl Identifiable for ChannelAdminLogEventActionChangeUsernames
Sourceconst CONSTRUCTOR_ID: u32 = 0xf04fb3a9
const CONSTRUCTOR_ID: u32 = 0xf04fb3a9
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeUsernames
impl PartialEq for ChannelAdminLogEventActionChangeUsernames
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeUsernames) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeUsernames) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeUsernames
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeUsernames
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeUsernames