pub struct ChannelAdminLogEventActionChangeWallpaper {
pub prev_value: WallPaper,
pub new_value: WallPaper,
}Expand description
channelAdminLogEventActionChangeWallpaper
Generated from:
channelAdminLogEventActionChangeWallpaper#31bb5d52 prev_value:WallPaper new_value:WallPaper = ChannelAdminLogEventActionFields
prev_value: WallPapernew_value: WallPaperTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionChangeWallpaper
impl Clone for ChannelAdminLogEventActionChangeWallpaper
Sourcefn clone(&self) -> ChannelAdminLogEventActionChangeWallpaper
fn clone(&self) -> ChannelAdminLogEventActionChangeWallpaper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionChangeWallpaper
impl Deserializable for ChannelAdminLogEventActionChangeWallpaper
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionChangeWallpaper> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionChangeWallpaper> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionChangeWallpaper) -> Self
fn from(x: ChannelAdminLogEventActionChangeWallpaper) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionChangeWallpaper
impl Identifiable for ChannelAdminLogEventActionChangeWallpaper
Sourceconst CONSTRUCTOR_ID: u32 = 0x31bb5d52
const CONSTRUCTOR_ID: u32 = 0x31bb5d52
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionChangeWallpaper
impl PartialEq for ChannelAdminLogEventActionChangeWallpaper
Sourcefn eq(&self, other: &ChannelAdminLogEventActionChangeWallpaper) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionChangeWallpaper) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeWallpaper
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionChangeWallpaper
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionChangeWallpaper