pub struct ChannelAdminLogEventActionCreateTopic {
pub topic: ForumTopic,
}Expand description
channelAdminLogEventActionCreateTopic
Generated from:
channelAdminLogEventActionCreateTopic#58707d28 topic:ForumTopic = ChannelAdminLogEventActionFields
topic: ForumTopicTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionCreateTopic
impl Clone for ChannelAdminLogEventActionCreateTopic
Sourcefn clone(&self) -> ChannelAdminLogEventActionCreateTopic
fn clone(&self) -> ChannelAdminLogEventActionCreateTopic
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionCreateTopic
impl Deserializable for ChannelAdminLogEventActionCreateTopic
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionCreateTopic> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionCreateTopic> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionCreateTopic) -> Self
fn from(x: ChannelAdminLogEventActionCreateTopic) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionCreateTopic
impl Identifiable for ChannelAdminLogEventActionCreateTopic
Sourceconst CONSTRUCTOR_ID: u32 = 0x58707d28
const CONSTRUCTOR_ID: u32 = 0x58707d28
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionCreateTopic
impl PartialEq for ChannelAdminLogEventActionCreateTopic
Sourcefn eq(&self, other: &ChannelAdminLogEventActionCreateTopic) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionCreateTopic) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionCreateTopic
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionCreateTopic
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionCreateTopic