pub struct ChannelAdminLogEventActionDefaultBannedRights {
pub prev_banned_rights: ChatBannedRights,
pub new_banned_rights: ChatBannedRights,
}Expand description
channelAdminLogEventActionDefaultBannedRights
Generated from:
channelAdminLogEventActionDefaultBannedRights#2df5fc0a prev_banned_rights:ChatBannedRights new_banned_rights:ChatBannedRights = ChannelAdminLogEventActionFields
prev_banned_rights: ChatBannedRightsnew_banned_rights: ChatBannedRightsTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionDefaultBannedRights
impl Clone for ChannelAdminLogEventActionDefaultBannedRights
Sourcefn clone(&self) -> ChannelAdminLogEventActionDefaultBannedRights
fn clone(&self) -> ChannelAdminLogEventActionDefaultBannedRights
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionDefaultBannedRights
impl Deserializable for ChannelAdminLogEventActionDefaultBannedRights
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionDefaultBannedRights> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionDefaultBannedRights> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionDefaultBannedRights) -> Self
fn from(x: ChannelAdminLogEventActionDefaultBannedRights) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionDefaultBannedRights
impl Identifiable for ChannelAdminLogEventActionDefaultBannedRights
Sourceconst CONSTRUCTOR_ID: u32 = 0x2df5fc0a
const CONSTRUCTOR_ID: u32 = 0x2df5fc0a
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionDefaultBannedRights
impl PartialEq for ChannelAdminLogEventActionDefaultBannedRights
Sourcefn eq(&self, other: &ChannelAdminLogEventActionDefaultBannedRights) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionDefaultBannedRights) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionDefaultBannedRights
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionDefaultBannedRights
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionDefaultBannedRights