pub struct ChannelAdminLogEventActionDeleteMessage {
pub message: Message,
}Expand description
channelAdminLogEventActionDeleteMessage
Generated from:
channelAdminLogEventActionDeleteMessage#42e047bb message:Message = ChannelAdminLogEventActionFields
message: MessageTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionDeleteMessage
impl Clone for ChannelAdminLogEventActionDeleteMessage
Sourcefn clone(&self) -> ChannelAdminLogEventActionDeleteMessage
fn clone(&self) -> ChannelAdminLogEventActionDeleteMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionDeleteMessage
impl Deserializable for ChannelAdminLogEventActionDeleteMessage
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionDeleteMessage> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionDeleteMessage> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionDeleteMessage) -> Self
fn from(x: ChannelAdminLogEventActionDeleteMessage) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionDeleteMessage
impl Identifiable for ChannelAdminLogEventActionDeleteMessage
Sourceconst CONSTRUCTOR_ID: u32 = 0x42e047bb
const CONSTRUCTOR_ID: u32 = 0x42e047bb
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionDeleteMessage
impl PartialEq for ChannelAdminLogEventActionDeleteMessage
Sourcefn eq(&self, other: &ChannelAdminLogEventActionDeleteMessage) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionDeleteMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionDeleteMessage
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionDeleteMessage
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionDeleteMessage