pub struct ChannelAdminLogEventActionDeleteTopic {
pub topic: ForumTopic,
}Expand description
channelAdminLogEventActionDeleteTopic
Generated from:
channelAdminLogEventActionDeleteTopic#ae168909 topic:ForumTopic = ChannelAdminLogEventActionFields
topic: ForumTopicTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionDeleteTopic
impl Clone for ChannelAdminLogEventActionDeleteTopic
Sourcefn clone(&self) -> ChannelAdminLogEventActionDeleteTopic
fn clone(&self) -> ChannelAdminLogEventActionDeleteTopic
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionDeleteTopic
impl Deserializable for ChannelAdminLogEventActionDeleteTopic
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionDeleteTopic> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionDeleteTopic> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionDeleteTopic) -> Self
fn from(x: ChannelAdminLogEventActionDeleteTopic) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionDeleteTopic
impl Identifiable for ChannelAdminLogEventActionDeleteTopic
Sourceconst CONSTRUCTOR_ID: u32 = 0xae168909
const CONSTRUCTOR_ID: u32 = 0xae168909
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionDeleteTopic
impl PartialEq for ChannelAdminLogEventActionDeleteTopic
Sourcefn eq(&self, other: &ChannelAdminLogEventActionDeleteTopic) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionDeleteTopic) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionDeleteTopic
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionDeleteTopic
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionDeleteTopic