pub struct ChannelAdminLogEventActionDiscardGroupCall {
pub call: InputGroupCall,
}Expand description
channelAdminLogEventActionDiscardGroupCall
Generated from:
channelAdminLogEventActionDiscardGroupCall#db9f9140 call:InputGroupCall = ChannelAdminLogEventActionFields
call: InputGroupCallTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionDiscardGroupCall
impl Clone for ChannelAdminLogEventActionDiscardGroupCall
Sourcefn clone(&self) -> ChannelAdminLogEventActionDiscardGroupCall
fn clone(&self) -> ChannelAdminLogEventActionDiscardGroupCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionDiscardGroupCall
impl Deserializable for ChannelAdminLogEventActionDiscardGroupCall
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionDiscardGroupCall> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionDiscardGroupCall> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionDiscardGroupCall) -> Self
fn from(x: ChannelAdminLogEventActionDiscardGroupCall) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionDiscardGroupCall
impl Identifiable for ChannelAdminLogEventActionDiscardGroupCall
Sourceconst CONSTRUCTOR_ID: u32 = 0xdb9f9140
const CONSTRUCTOR_ID: u32 = 0xdb9f9140
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionDiscardGroupCall
impl PartialEq for ChannelAdminLogEventActionDiscardGroupCall
Sourcefn eq(&self, other: &ChannelAdminLogEventActionDiscardGroupCall) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionDiscardGroupCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionDiscardGroupCall
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionDiscardGroupCall
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionDiscardGroupCall