pub struct ChannelAdminLogEventActionEditMessage {
pub prev_message: Message,
pub new_message: Message,
}Expand description
channelAdminLogEventActionEditMessage
Generated from:
channelAdminLogEventActionEditMessage#709b2405 prev_message:Message new_message:Message = ChannelAdminLogEventActionFields
prev_message: Messagenew_message: MessageTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionEditMessage
impl Clone for ChannelAdminLogEventActionEditMessage
Sourcefn clone(&self) -> ChannelAdminLogEventActionEditMessage
fn clone(&self) -> ChannelAdminLogEventActionEditMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionEditMessage
impl Deserializable for ChannelAdminLogEventActionEditMessage
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionEditMessage> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionEditMessage> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionEditMessage) -> Self
fn from(x: ChannelAdminLogEventActionEditMessage) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionEditMessage
impl Identifiable for ChannelAdminLogEventActionEditMessage
Sourceconst CONSTRUCTOR_ID: u32 = 0x709b2405
const CONSTRUCTOR_ID: u32 = 0x709b2405
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionEditMessage
impl PartialEq for ChannelAdminLogEventActionEditMessage
Sourcefn eq(&self, other: &ChannelAdminLogEventActionEditMessage) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionEditMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionEditMessage
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionEditMessage
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionEditMessage