pub struct ChannelAdminLogEventActionEditTopic {
pub prev_topic: ForumTopic,
pub new_topic: ForumTopic,
}Expand description
channelAdminLogEventActionEditTopic
Generated from:
channelAdminLogEventActionEditTopic#f06fe208 prev_topic:ForumTopic new_topic:ForumTopic = ChannelAdminLogEventActionFields
prev_topic: ForumTopicnew_topic: ForumTopicTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionEditTopic
impl Clone for ChannelAdminLogEventActionEditTopic
Sourcefn clone(&self) -> ChannelAdminLogEventActionEditTopic
fn clone(&self) -> ChannelAdminLogEventActionEditTopic
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionEditTopic
impl Deserializable for ChannelAdminLogEventActionEditTopic
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionEditTopic> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionEditTopic> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionEditTopic) -> Self
fn from(x: ChannelAdminLogEventActionEditTopic) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionEditTopic
impl Identifiable for ChannelAdminLogEventActionEditTopic
Sourceconst CONSTRUCTOR_ID: u32 = 0xf06fe208
const CONSTRUCTOR_ID: u32 = 0xf06fe208
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionEditTopic
impl PartialEq for ChannelAdminLogEventActionEditTopic
Sourcefn eq(&self, other: &ChannelAdminLogEventActionEditTopic) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionEditTopic) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionEditTopic
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionEditTopic
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionEditTopic