pub struct ChannelAdminLogEventActionExportedInviteDelete {
pub invite: ExportedChatInvite,
}Expand description
channelAdminLogEventActionExportedInviteDelete
Generated from:
channelAdminLogEventActionExportedInviteDelete#5a50fca4 invite:ExportedChatInvite = ChannelAdminLogEventActionFields
invite: ExportedChatInviteTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionExportedInviteDelete
impl Clone for ChannelAdminLogEventActionExportedInviteDelete
Sourcefn clone(&self) -> ChannelAdminLogEventActionExportedInviteDelete
fn clone(&self) -> ChannelAdminLogEventActionExportedInviteDelete
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionExportedInviteDelete
impl Deserializable for ChannelAdminLogEventActionExportedInviteDelete
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionExportedInviteDelete> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionExportedInviteDelete> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionExportedInviteDelete) -> Self
fn from(x: ChannelAdminLogEventActionExportedInviteDelete) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionExportedInviteDelete
impl Identifiable for ChannelAdminLogEventActionExportedInviteDelete
Sourceconst CONSTRUCTOR_ID: u32 = 0x5a50fca4
const CONSTRUCTOR_ID: u32 = 0x5a50fca4
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionExportedInviteDelete
impl PartialEq for ChannelAdminLogEventActionExportedInviteDelete
Sourcefn eq(&self, other: &ChannelAdminLogEventActionExportedInviteDelete) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionExportedInviteDelete) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionExportedInviteDelete
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionExportedInviteDelete
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionExportedInviteDelete