pub struct ChannelAdminLogEventActionExportedInviteEdit {
pub prev_invite: ExportedChatInvite,
pub new_invite: ExportedChatInvite,
}Expand description
channelAdminLogEventActionExportedInviteEdit
Generated from:
channelAdminLogEventActionExportedInviteEdit#e90ebb59 prev_invite:ExportedChatInvite new_invite:ExportedChatInvite = ChannelAdminLogEventActionFields
prev_invite: ExportedChatInvitenew_invite: ExportedChatInviteTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionExportedInviteEdit
impl Clone for ChannelAdminLogEventActionExportedInviteEdit
Sourcefn clone(&self) -> ChannelAdminLogEventActionExportedInviteEdit
fn clone(&self) -> ChannelAdminLogEventActionExportedInviteEdit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionExportedInviteEdit
impl Deserializable for ChannelAdminLogEventActionExportedInviteEdit
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionExportedInviteEdit> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionExportedInviteEdit> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionExportedInviteEdit) -> Self
fn from(x: ChannelAdminLogEventActionExportedInviteEdit) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionExportedInviteEdit
impl Identifiable for ChannelAdminLogEventActionExportedInviteEdit
Sourceconst CONSTRUCTOR_ID: u32 = 0xe90ebb59
const CONSTRUCTOR_ID: u32 = 0xe90ebb59
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionExportedInviteEdit
impl PartialEq for ChannelAdminLogEventActionExportedInviteEdit
Sourcefn eq(&self, other: &ChannelAdminLogEventActionExportedInviteEdit) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionExportedInviteEdit) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionExportedInviteEdit
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionExportedInviteEdit
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionExportedInviteEdit