pub struct ChannelAdminLogEventActionExportedInviteRevoke {
pub invite: ExportedChatInvite,
}Expand description
channelAdminLogEventActionExportedInviteRevoke
Generated from:
channelAdminLogEventActionExportedInviteRevoke#410a134e invite:ExportedChatInvite = ChannelAdminLogEventActionFields
invite: ExportedChatInviteTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionExportedInviteRevoke
impl Clone for ChannelAdminLogEventActionExportedInviteRevoke
Sourcefn clone(&self) -> ChannelAdminLogEventActionExportedInviteRevoke
fn clone(&self) -> ChannelAdminLogEventActionExportedInviteRevoke
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionExportedInviteRevoke
impl Deserializable for ChannelAdminLogEventActionExportedInviteRevoke
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionExportedInviteRevoke> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionExportedInviteRevoke> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionExportedInviteRevoke) -> Self
fn from(x: ChannelAdminLogEventActionExportedInviteRevoke) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionExportedInviteRevoke
impl Identifiable for ChannelAdminLogEventActionExportedInviteRevoke
Sourceconst CONSTRUCTOR_ID: u32 = 0x410a134e
const CONSTRUCTOR_ID: u32 = 0x410a134e
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionExportedInviteRevoke
impl PartialEq for ChannelAdminLogEventActionExportedInviteRevoke
Sourcefn eq(&self, other: &ChannelAdminLogEventActionExportedInviteRevoke) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionExportedInviteRevoke) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionExportedInviteRevoke
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionExportedInviteRevoke
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionExportedInviteRevoke