pub struct ChannelAdminLogEventActionParticipantEditRank {
pub user_id: i64,
pub prev_rank: String,
pub new_rank: String,
}Expand description
channelAdminLogEventActionParticipantEditRank
Generated from:
channelAdminLogEventActionParticipantEditRank#5806b4ec user_id:long prev_rank:string new_rank:string = ChannelAdminLogEventActionFields
user_id: i64prev_rank: Stringnew_rank: StringTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionParticipantEditRank
impl Clone for ChannelAdminLogEventActionParticipantEditRank
Sourcefn clone(&self) -> ChannelAdminLogEventActionParticipantEditRank
fn clone(&self) -> ChannelAdminLogEventActionParticipantEditRank
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionParticipantEditRank
impl Deserializable for ChannelAdminLogEventActionParticipantEditRank
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionParticipantEditRank> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionParticipantEditRank> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionParticipantEditRank) -> Self
fn from(x: ChannelAdminLogEventActionParticipantEditRank) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionParticipantEditRank
impl Identifiable for ChannelAdminLogEventActionParticipantEditRank
Sourceconst CONSTRUCTOR_ID: u32 = 0x5806b4ec
const CONSTRUCTOR_ID: u32 = 0x5806b4ec
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionParticipantEditRank
impl PartialEq for ChannelAdminLogEventActionParticipantEditRank
Sourcefn eq(&self, other: &ChannelAdminLogEventActionParticipantEditRank) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionParticipantEditRank) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantEditRank
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantEditRank
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionParticipantEditRank