pub struct ChannelAdminLogEventActionParticipantInvite {
pub participant: ChannelParticipant,
}Expand description
channelAdminLogEventActionParticipantInvite
Generated from:
channelAdminLogEventActionParticipantInvite#e31c34d8 participant:ChannelParticipant = ChannelAdminLogEventActionFields
participant: ChannelParticipantTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionParticipantInvite
impl Clone for ChannelAdminLogEventActionParticipantInvite
Sourcefn clone(&self) -> ChannelAdminLogEventActionParticipantInvite
fn clone(&self) -> ChannelAdminLogEventActionParticipantInvite
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionParticipantInvite
impl Deserializable for ChannelAdminLogEventActionParticipantInvite
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionParticipantInvite> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionParticipantInvite> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionParticipantInvite) -> Self
fn from(x: ChannelAdminLogEventActionParticipantInvite) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionParticipantInvite
impl Identifiable for ChannelAdminLogEventActionParticipantInvite
Sourceconst CONSTRUCTOR_ID: u32 = 0xe31c34d8
const CONSTRUCTOR_ID: u32 = 0xe31c34d8
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionParticipantInvite
impl PartialEq for ChannelAdminLogEventActionParticipantInvite
Sourcefn eq(&self, other: &ChannelAdminLogEventActionParticipantInvite) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionParticipantInvite) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantInvite
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantInvite
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionParticipantInvite