pub struct ChannelAdminLogEventActionParticipantJoinByInvite {
pub via_chatlist: bool,
pub invite: ExportedChatInvite,
}Expand description
channelAdminLogEventActionParticipantJoinByInvite
Generated from:
channelAdminLogEventActionParticipantJoinByInvite#fe9fc158 flags:# via_chatlist:flags.0?true invite:ExportedChatInvite = ChannelAdminLogEventActionFields
via_chatlist: boolinvite: ExportedChatInviteTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionParticipantJoinByInvite
impl Clone for ChannelAdminLogEventActionParticipantJoinByInvite
Sourcefn clone(&self) -> ChannelAdminLogEventActionParticipantJoinByInvite
fn clone(&self) -> ChannelAdminLogEventActionParticipantJoinByInvite
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionParticipantJoinByInvite
impl Deserializable for ChannelAdminLogEventActionParticipantJoinByInvite
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionParticipantJoinByInvite> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionParticipantJoinByInvite> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionParticipantJoinByInvite) -> Self
fn from(x: ChannelAdminLogEventActionParticipantJoinByInvite) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionParticipantJoinByInvite
impl Identifiable for ChannelAdminLogEventActionParticipantJoinByInvite
Sourceconst CONSTRUCTOR_ID: u32 = 0xfe9fc158
const CONSTRUCTOR_ID: u32 = 0xfe9fc158
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionParticipantJoinByInvite
impl PartialEq for ChannelAdminLogEventActionParticipantJoinByInvite
Sourcefn eq(&self, other: &ChannelAdminLogEventActionParticipantJoinByInvite) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionParticipantJoinByInvite) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantJoinByInvite
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantJoinByInvite
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionParticipantJoinByInvite