pub struct ChannelAdminLogEventActionParticipantJoinByRequest {
pub invite: ExportedChatInvite,
pub approved_by: i64,
}Expand description
channelAdminLogEventActionParticipantJoinByRequest
Generated from:
channelAdminLogEventActionParticipantJoinByRequest#afb6144a invite:ExportedChatInvite approved_by:long = ChannelAdminLogEventActionFields
invite: ExportedChatInviteapproved_by: i64Trait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionParticipantJoinByRequest
impl Clone for ChannelAdminLogEventActionParticipantJoinByRequest
Sourcefn clone(&self) -> ChannelAdminLogEventActionParticipantJoinByRequest
fn clone(&self) -> ChannelAdminLogEventActionParticipantJoinByRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionParticipantJoinByRequest
impl Deserializable for ChannelAdminLogEventActionParticipantJoinByRequest
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionParticipantJoinByRequest> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionParticipantJoinByRequest> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionParticipantJoinByRequest) -> Self
fn from(x: ChannelAdminLogEventActionParticipantJoinByRequest) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionParticipantJoinByRequest
impl Identifiable for ChannelAdminLogEventActionParticipantJoinByRequest
Sourceconst CONSTRUCTOR_ID: u32 = 0xafb6144a
const CONSTRUCTOR_ID: u32 = 0xafb6144a
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionParticipantJoinByRequest
impl PartialEq for ChannelAdminLogEventActionParticipantJoinByRequest
Sourcefn eq(&self, other: &ChannelAdminLogEventActionParticipantJoinByRequest) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionParticipantJoinByRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantJoinByRequest
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantJoinByRequest
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionParticipantJoinByRequest