pub struct ChannelAdminLogEventActionParticipantMute {
pub participant: GroupCallParticipant,
}Expand description
channelAdminLogEventActionParticipantMute
Generated from:
channelAdminLogEventActionParticipantMute#f92424d2 participant:GroupCallParticipant = ChannelAdminLogEventActionFields
participant: GroupCallParticipantTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionParticipantMute
impl Clone for ChannelAdminLogEventActionParticipantMute
Sourcefn clone(&self) -> ChannelAdminLogEventActionParticipantMute
fn clone(&self) -> ChannelAdminLogEventActionParticipantMute
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionParticipantMute
impl Deserializable for ChannelAdminLogEventActionParticipantMute
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionParticipantMute> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionParticipantMute> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionParticipantMute) -> Self
fn from(x: ChannelAdminLogEventActionParticipantMute) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionParticipantMute
impl Identifiable for ChannelAdminLogEventActionParticipantMute
Sourceconst CONSTRUCTOR_ID: u32 = 0xf92424d2
const CONSTRUCTOR_ID: u32 = 0xf92424d2
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionParticipantMute
impl PartialEq for ChannelAdminLogEventActionParticipantMute
Sourcefn eq(&self, other: &ChannelAdminLogEventActionParticipantMute) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionParticipantMute) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantMute
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantMute
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionParticipantMute