pub struct ChannelAdminLogEventActionParticipantSubExtend {
pub prev_participant: ChannelParticipant,
pub new_participant: ChannelParticipant,
}Expand description
channelAdminLogEventActionParticipantSubExtend
Generated from:
channelAdminLogEventActionParticipantSubExtend#64642db3 prev_participant:ChannelParticipant new_participant:ChannelParticipant = ChannelAdminLogEventActionFields
prev_participant: ChannelParticipantnew_participant: ChannelParticipantTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionParticipantSubExtend
impl Clone for ChannelAdminLogEventActionParticipantSubExtend
Sourcefn clone(&self) -> ChannelAdminLogEventActionParticipantSubExtend
fn clone(&self) -> ChannelAdminLogEventActionParticipantSubExtend
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionParticipantSubExtend
impl Deserializable for ChannelAdminLogEventActionParticipantSubExtend
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionParticipantSubExtend> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionParticipantSubExtend> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionParticipantSubExtend) -> Self
fn from(x: ChannelAdminLogEventActionParticipantSubExtend) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionParticipantSubExtend
impl Identifiable for ChannelAdminLogEventActionParticipantSubExtend
Sourceconst CONSTRUCTOR_ID: u32 = 0x64642db3
const CONSTRUCTOR_ID: u32 = 0x64642db3
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionParticipantSubExtend
impl PartialEq for ChannelAdminLogEventActionParticipantSubExtend
Sourcefn eq(&self, other: &ChannelAdminLogEventActionParticipantSubExtend) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionParticipantSubExtend) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantSubExtend
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantSubExtend
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionParticipantSubExtend