pub struct ChannelAdminLogEventActionParticipantToggleAdmin {
pub prev_participant: ChannelParticipant,
pub new_participant: ChannelParticipant,
}Expand description
channelAdminLogEventActionParticipantToggleAdmin
Generated from:
channelAdminLogEventActionParticipantToggleAdmin#d5676710 prev_participant:ChannelParticipant new_participant:ChannelParticipant = ChannelAdminLogEventActionFields
prev_participant: ChannelParticipantnew_participant: ChannelParticipantTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionParticipantToggleAdmin
impl Clone for ChannelAdminLogEventActionParticipantToggleAdmin
Sourcefn clone(&self) -> ChannelAdminLogEventActionParticipantToggleAdmin
fn clone(&self) -> ChannelAdminLogEventActionParticipantToggleAdmin
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionParticipantToggleAdmin
impl Deserializable for ChannelAdminLogEventActionParticipantToggleAdmin
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionParticipantToggleAdmin> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionParticipantToggleAdmin> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionParticipantToggleAdmin) -> Self
fn from(x: ChannelAdminLogEventActionParticipantToggleAdmin) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionParticipantToggleAdmin
impl Identifiable for ChannelAdminLogEventActionParticipantToggleAdmin
Sourceconst CONSTRUCTOR_ID: u32 = 0xd5676710
const CONSTRUCTOR_ID: u32 = 0xd5676710
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionParticipantToggleAdmin
impl PartialEq for ChannelAdminLogEventActionParticipantToggleAdmin
Sourcefn eq(&self, other: &ChannelAdminLogEventActionParticipantToggleAdmin) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionParticipantToggleAdmin) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantToggleAdmin
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantToggleAdmin
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionParticipantToggleAdmin