pub struct ChannelAdminLogEventActionParticipantToggleBan {
pub prev_participant: ChannelParticipant,
pub new_participant: ChannelParticipant,
}Expand description
channelAdminLogEventActionParticipantToggleBan
Generated from:
channelAdminLogEventActionParticipantToggleBan#e6d83d7e prev_participant:ChannelParticipant new_participant:ChannelParticipant = ChannelAdminLogEventActionFields
prev_participant: ChannelParticipantnew_participant: ChannelParticipantTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionParticipantToggleBan
impl Clone for ChannelAdminLogEventActionParticipantToggleBan
Sourcefn clone(&self) -> ChannelAdminLogEventActionParticipantToggleBan
fn clone(&self) -> ChannelAdminLogEventActionParticipantToggleBan
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionParticipantToggleBan
impl Deserializable for ChannelAdminLogEventActionParticipantToggleBan
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionParticipantToggleBan> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionParticipantToggleBan> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionParticipantToggleBan) -> Self
fn from(x: ChannelAdminLogEventActionParticipantToggleBan) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionParticipantToggleBan
impl Identifiable for ChannelAdminLogEventActionParticipantToggleBan
Sourceconst CONSTRUCTOR_ID: u32 = 0xe6d83d7e
const CONSTRUCTOR_ID: u32 = 0xe6d83d7e
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionParticipantToggleBan
impl PartialEq for ChannelAdminLogEventActionParticipantToggleBan
Sourcefn eq(&self, other: &ChannelAdminLogEventActionParticipantToggleBan) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionParticipantToggleBan) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantToggleBan
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantToggleBan
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionParticipantToggleBan