pub struct ChannelAdminLogEventActionParticipantUnmute {
pub participant: GroupCallParticipant,
}Expand description
channelAdminLogEventActionParticipantUnmute
Generated from:
channelAdminLogEventActionParticipantUnmute#e64429c0 participant:GroupCallParticipant = ChannelAdminLogEventActionFields
participant: GroupCallParticipantTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionParticipantUnmute
impl Clone for ChannelAdminLogEventActionParticipantUnmute
Sourcefn clone(&self) -> ChannelAdminLogEventActionParticipantUnmute
fn clone(&self) -> ChannelAdminLogEventActionParticipantUnmute
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionParticipantUnmute
impl Deserializable for ChannelAdminLogEventActionParticipantUnmute
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionParticipantUnmute> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionParticipantUnmute> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionParticipantUnmute) -> Self
fn from(x: ChannelAdminLogEventActionParticipantUnmute) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionParticipantUnmute
impl Identifiable for ChannelAdminLogEventActionParticipantUnmute
Sourceconst CONSTRUCTOR_ID: u32 = 0xe64429c0
const CONSTRUCTOR_ID: u32 = 0xe64429c0
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionParticipantUnmute
impl PartialEq for ChannelAdminLogEventActionParticipantUnmute
Sourcefn eq(&self, other: &ChannelAdminLogEventActionParticipantUnmute) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionParticipantUnmute) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantUnmute
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantUnmute
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionParticipantUnmute