pub struct ChannelAdminLogEventActionParticipantVolume {
pub participant: GroupCallParticipant,
}Expand description
channelAdminLogEventActionParticipantVolume
Generated from:
channelAdminLogEventActionParticipantVolume#3e7f6847 participant:GroupCallParticipant = ChannelAdminLogEventActionFields
participant: GroupCallParticipantTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionParticipantVolume
impl Clone for ChannelAdminLogEventActionParticipantVolume
Sourcefn clone(&self) -> ChannelAdminLogEventActionParticipantVolume
fn clone(&self) -> ChannelAdminLogEventActionParticipantVolume
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionParticipantVolume
impl Deserializable for ChannelAdminLogEventActionParticipantVolume
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionParticipantVolume> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionParticipantVolume> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionParticipantVolume) -> Self
fn from(x: ChannelAdminLogEventActionParticipantVolume) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionParticipantVolume
impl Identifiable for ChannelAdminLogEventActionParticipantVolume
Sourceconst CONSTRUCTOR_ID: u32 = 0x3e7f6847
const CONSTRUCTOR_ID: u32 = 0x3e7f6847
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionParticipantVolume
impl PartialEq for ChannelAdminLogEventActionParticipantVolume
Sourcefn eq(&self, other: &ChannelAdminLogEventActionParticipantVolume) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionParticipantVolume) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantVolume
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionParticipantVolume
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionParticipantVolume