pub struct ChannelAdminLogEventActionPinTopic {
pub prev_topic: Option<ForumTopic>,
pub new_topic: Option<ForumTopic>,
}Expand description
channelAdminLogEventActionPinTopic
Generated from:
channelAdminLogEventActionPinTopic#5d8d353b flags:# prev_topic:flags.0?ForumTopic new_topic:flags.1?ForumTopic = ChannelAdminLogEventActionFields
prev_topic: Option<ForumTopic>new_topic: Option<ForumTopic>Trait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionPinTopic
impl Clone for ChannelAdminLogEventActionPinTopic
Sourcefn clone(&self) -> ChannelAdminLogEventActionPinTopic
fn clone(&self) -> ChannelAdminLogEventActionPinTopic
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionPinTopic
impl Deserializable for ChannelAdminLogEventActionPinTopic
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionPinTopic> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionPinTopic> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionPinTopic) -> Self
fn from(x: ChannelAdminLogEventActionPinTopic) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionPinTopic
impl Identifiable for ChannelAdminLogEventActionPinTopic
Sourceconst CONSTRUCTOR_ID: u32 = 0x5d8d353b
const CONSTRUCTOR_ID: u32 = 0x5d8d353b
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionPinTopic
impl PartialEq for ChannelAdminLogEventActionPinTopic
Sourcefn eq(&self, other: &ChannelAdminLogEventActionPinTopic) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionPinTopic) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionPinTopic
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionPinTopic
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionPinTopic