pub struct ChannelAdminLogEventActionSendMessage {
pub message: Message,
}Expand description
channelAdminLogEventActionSendMessage
Generated from:
channelAdminLogEventActionSendMessage#278f2868 message:Message = ChannelAdminLogEventActionFields
message: MessageTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionSendMessage
impl Clone for ChannelAdminLogEventActionSendMessage
Sourcefn clone(&self) -> ChannelAdminLogEventActionSendMessage
fn clone(&self) -> ChannelAdminLogEventActionSendMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionSendMessage
impl Deserializable for ChannelAdminLogEventActionSendMessage
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionSendMessage> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionSendMessage> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionSendMessage) -> Self
fn from(x: ChannelAdminLogEventActionSendMessage) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionSendMessage
impl Identifiable for ChannelAdminLogEventActionSendMessage
Sourceconst CONSTRUCTOR_ID: u32 = 0x278f2868
const CONSTRUCTOR_ID: u32 = 0x278f2868
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionSendMessage
impl PartialEq for ChannelAdminLogEventActionSendMessage
Sourcefn eq(&self, other: &ChannelAdminLogEventActionSendMessage) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionSendMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionSendMessage
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionSendMessage
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionSendMessage