pub struct ChannelAdminLogEventActionStartGroupCall {
pub call: InputGroupCall,
}Expand description
channelAdminLogEventActionStartGroupCall
Generated from:
channelAdminLogEventActionStartGroupCall#23209745 call:InputGroupCall = ChannelAdminLogEventActionFields
call: InputGroupCallTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionStartGroupCall
impl Clone for ChannelAdminLogEventActionStartGroupCall
Sourcefn clone(&self) -> ChannelAdminLogEventActionStartGroupCall
fn clone(&self) -> ChannelAdminLogEventActionStartGroupCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionStartGroupCall
impl Deserializable for ChannelAdminLogEventActionStartGroupCall
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionStartGroupCall> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionStartGroupCall> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionStartGroupCall) -> Self
fn from(x: ChannelAdminLogEventActionStartGroupCall) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionStartGroupCall
impl Identifiable for ChannelAdminLogEventActionStartGroupCall
Sourceconst CONSTRUCTOR_ID: u32 = 0x23209745
const CONSTRUCTOR_ID: u32 = 0x23209745
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionStartGroupCall
impl PartialEq for ChannelAdminLogEventActionStartGroupCall
Sourcefn eq(&self, other: &ChannelAdminLogEventActionStartGroupCall) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionStartGroupCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionStartGroupCall
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionStartGroupCall
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionStartGroupCall