pub struct ChannelAdminLogEventActionStopPoll {
pub message: Message,
}Expand description
channelAdminLogEventActionStopPoll
Generated from:
channelAdminLogEventActionStopPoll#8f079643 message:Message = ChannelAdminLogEventActionFields
message: MessageTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionStopPoll
impl Clone for ChannelAdminLogEventActionStopPoll
Sourcefn clone(&self) -> ChannelAdminLogEventActionStopPoll
fn clone(&self) -> ChannelAdminLogEventActionStopPoll
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionStopPoll
impl Deserializable for ChannelAdminLogEventActionStopPoll
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionStopPoll> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionStopPoll> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionStopPoll) -> Self
fn from(x: ChannelAdminLogEventActionStopPoll) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionStopPoll
impl Identifiable for ChannelAdminLogEventActionStopPoll
Sourceconst CONSTRUCTOR_ID: u32 = 0x8f079643
const CONSTRUCTOR_ID: u32 = 0x8f079643
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionStopPoll
impl PartialEq for ChannelAdminLogEventActionStopPoll
Sourcefn eq(&self, other: &ChannelAdminLogEventActionStopPoll) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionStopPoll) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionStopPoll
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionStopPoll
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionStopPoll