pub struct ChannelAdminLogEventActionToggleAntiSpam {
pub new_value: bool,
}Expand description
channelAdminLogEventActionToggleAntiSpam
Generated from:
channelAdminLogEventActionToggleAntiSpam#64f36dfc new_value:Bool = ChannelAdminLogEventActionFields
new_value: boolTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionToggleAntiSpam
impl Clone for ChannelAdminLogEventActionToggleAntiSpam
Sourcefn clone(&self) -> ChannelAdminLogEventActionToggleAntiSpam
fn clone(&self) -> ChannelAdminLogEventActionToggleAntiSpam
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionToggleAntiSpam
impl Deserializable for ChannelAdminLogEventActionToggleAntiSpam
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionToggleAntiSpam> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionToggleAntiSpam> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionToggleAntiSpam) -> Self
fn from(x: ChannelAdminLogEventActionToggleAntiSpam) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionToggleAntiSpam
impl Identifiable for ChannelAdminLogEventActionToggleAntiSpam
Sourceconst CONSTRUCTOR_ID: u32 = 0x64f36dfc
const CONSTRUCTOR_ID: u32 = 0x64f36dfc
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionToggleAntiSpam
impl PartialEq for ChannelAdminLogEventActionToggleAntiSpam
Sourcefn eq(&self, other: &ChannelAdminLogEventActionToggleAntiSpam) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionToggleAntiSpam) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleAntiSpam
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleAntiSpam
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionToggleAntiSpam