pub struct ChannelAdminLogEventActionToggleAutotranslation {
pub new_value: bool,
}Expand description
channelAdminLogEventActionToggleAutotranslation
Generated from:
channelAdminLogEventActionToggleAutotranslation#c517f77e new_value:Bool = ChannelAdminLogEventActionFields
new_value: boolTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionToggleAutotranslation
impl Clone for ChannelAdminLogEventActionToggleAutotranslation
Sourcefn clone(&self) -> ChannelAdminLogEventActionToggleAutotranslation
fn clone(&self) -> ChannelAdminLogEventActionToggleAutotranslation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionToggleAutotranslation
impl Deserializable for ChannelAdminLogEventActionToggleAutotranslation
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionToggleAutotranslation> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionToggleAutotranslation> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionToggleAutotranslation) -> Self
fn from(x: ChannelAdminLogEventActionToggleAutotranslation) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionToggleAutotranslation
impl Identifiable for ChannelAdminLogEventActionToggleAutotranslation
Sourceconst CONSTRUCTOR_ID: u32 = 0xc517f77e
const CONSTRUCTOR_ID: u32 = 0xc517f77e
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionToggleAutotranslation
impl PartialEq for ChannelAdminLogEventActionToggleAutotranslation
Sourcefn eq(&self, other: &ChannelAdminLogEventActionToggleAutotranslation) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionToggleAutotranslation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleAutotranslation
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleAutotranslation
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionToggleAutotranslation