pub struct ChannelAdminLogEventActionToggleForum {
pub new_value: bool,
}Expand description
channelAdminLogEventActionToggleForum
Generated from:
channelAdminLogEventActionToggleForum#2cc6383 new_value:Bool = ChannelAdminLogEventActionFields
new_value: boolTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionToggleForum
impl Clone for ChannelAdminLogEventActionToggleForum
Sourcefn clone(&self) -> ChannelAdminLogEventActionToggleForum
fn clone(&self) -> ChannelAdminLogEventActionToggleForum
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionToggleForum
impl Deserializable for ChannelAdminLogEventActionToggleForum
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionToggleForum> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionToggleForum> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionToggleForum) -> Self
fn from(x: ChannelAdminLogEventActionToggleForum) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionToggleForum
impl Identifiable for ChannelAdminLogEventActionToggleForum
Sourceconst CONSTRUCTOR_ID: u32 = 0x02cc6383
const CONSTRUCTOR_ID: u32 = 0x02cc6383
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionToggleForum
impl PartialEq for ChannelAdminLogEventActionToggleForum
Sourcefn eq(&self, other: &ChannelAdminLogEventActionToggleForum) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionToggleForum) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleForum
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleForum
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionToggleForum