pub struct ChannelAdminLogEventActionToggleGroupCallSetting {
pub join_muted: bool,
}Expand description
channelAdminLogEventActionToggleGroupCallSetting
Generated from:
channelAdminLogEventActionToggleGroupCallSetting#56d6a247 join_muted:Bool = ChannelAdminLogEventActionFields
join_muted: boolTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionToggleGroupCallSetting
impl Clone for ChannelAdminLogEventActionToggleGroupCallSetting
Sourcefn clone(&self) -> ChannelAdminLogEventActionToggleGroupCallSetting
fn clone(&self) -> ChannelAdminLogEventActionToggleGroupCallSetting
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionToggleGroupCallSetting
impl Deserializable for ChannelAdminLogEventActionToggleGroupCallSetting
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionToggleGroupCallSetting> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionToggleGroupCallSetting> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionToggleGroupCallSetting) -> Self
fn from(x: ChannelAdminLogEventActionToggleGroupCallSetting) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionToggleGroupCallSetting
impl Identifiable for ChannelAdminLogEventActionToggleGroupCallSetting
Sourceconst CONSTRUCTOR_ID: u32 = 0x56d6a247
const CONSTRUCTOR_ID: u32 = 0x56d6a247
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionToggleGroupCallSetting
impl PartialEq for ChannelAdminLogEventActionToggleGroupCallSetting
Sourcefn eq(&self, other: &ChannelAdminLogEventActionToggleGroupCallSetting) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionToggleGroupCallSetting) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleGroupCallSetting
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleGroupCallSetting
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionToggleGroupCallSetting