pub struct ChannelAdminLogEventActionToggleInvites {
pub new_value: bool,
}Expand description
channelAdminLogEventActionToggleInvites
Generated from:
channelAdminLogEventActionToggleInvites#1b7907ae new_value:Bool = ChannelAdminLogEventActionFields
new_value: boolTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionToggleInvites
impl Clone for ChannelAdminLogEventActionToggleInvites
Sourcefn clone(&self) -> ChannelAdminLogEventActionToggleInvites
fn clone(&self) -> ChannelAdminLogEventActionToggleInvites
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionToggleInvites
impl Deserializable for ChannelAdminLogEventActionToggleInvites
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionToggleInvites> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionToggleInvites> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionToggleInvites) -> Self
fn from(x: ChannelAdminLogEventActionToggleInvites) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionToggleInvites
impl Identifiable for ChannelAdminLogEventActionToggleInvites
Sourceconst CONSTRUCTOR_ID: u32 = 0x1b7907ae
const CONSTRUCTOR_ID: u32 = 0x1b7907ae
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionToggleInvites
impl PartialEq for ChannelAdminLogEventActionToggleInvites
Sourcefn eq(&self, other: &ChannelAdminLogEventActionToggleInvites) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionToggleInvites) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleInvites
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleInvites
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionToggleInvites