pub struct ChannelAdminLogEventActionToggleNoForwards {
pub new_value: bool,
}Expand description
channelAdminLogEventActionToggleNoForwards
Generated from:
channelAdminLogEventActionToggleNoForwards#cb2ac766 new_value:Bool = ChannelAdminLogEventActionFields
new_value: boolTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionToggleNoForwards
impl Clone for ChannelAdminLogEventActionToggleNoForwards
Sourcefn clone(&self) -> ChannelAdminLogEventActionToggleNoForwards
fn clone(&self) -> ChannelAdminLogEventActionToggleNoForwards
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionToggleNoForwards
impl Deserializable for ChannelAdminLogEventActionToggleNoForwards
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionToggleNoForwards> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionToggleNoForwards> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionToggleNoForwards) -> Self
fn from(x: ChannelAdminLogEventActionToggleNoForwards) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionToggleNoForwards
impl Identifiable for ChannelAdminLogEventActionToggleNoForwards
Sourceconst CONSTRUCTOR_ID: u32 = 0xcb2ac766
const CONSTRUCTOR_ID: u32 = 0xcb2ac766
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionToggleNoForwards
impl PartialEq for ChannelAdminLogEventActionToggleNoForwards
Sourcefn eq(&self, other: &ChannelAdminLogEventActionToggleNoForwards) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionToggleNoForwards) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleNoForwards
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleNoForwards
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionToggleNoForwards