pub struct ChannelAdminLogEventActionTogglePreHistoryHidden {
pub new_value: bool,
}Expand description
channelAdminLogEventActionTogglePreHistoryHidden
Generated from:
channelAdminLogEventActionTogglePreHistoryHidden#5f5c95f1 new_value:Bool = ChannelAdminLogEventActionFields
new_value: boolTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionTogglePreHistoryHidden
impl Clone for ChannelAdminLogEventActionTogglePreHistoryHidden
Sourcefn clone(&self) -> ChannelAdminLogEventActionTogglePreHistoryHidden
fn clone(&self) -> ChannelAdminLogEventActionTogglePreHistoryHidden
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionTogglePreHistoryHidden
impl Deserializable for ChannelAdminLogEventActionTogglePreHistoryHidden
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionTogglePreHistoryHidden> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionTogglePreHistoryHidden> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionTogglePreHistoryHidden) -> Self
fn from(x: ChannelAdminLogEventActionTogglePreHistoryHidden) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionTogglePreHistoryHidden
impl Identifiable for ChannelAdminLogEventActionTogglePreHistoryHidden
Sourceconst CONSTRUCTOR_ID: u32 = 0x5f5c95f1
const CONSTRUCTOR_ID: u32 = 0x5f5c95f1
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionTogglePreHistoryHidden
impl PartialEq for ChannelAdminLogEventActionTogglePreHistoryHidden
Sourcefn eq(&self, other: &ChannelAdminLogEventActionTogglePreHistoryHidden) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionTogglePreHistoryHidden) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionTogglePreHistoryHidden
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionTogglePreHistoryHidden
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionTogglePreHistoryHidden