pub struct ChannelAdminLogEventActionToggleSignatureProfiles {
pub new_value: bool,
}Expand description
channelAdminLogEventActionToggleSignatureProfiles
Generated from:
channelAdminLogEventActionToggleSignatureProfiles#60a79c79 new_value:Bool = ChannelAdminLogEventActionFields
new_value: boolTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionToggleSignatureProfiles
impl Clone for ChannelAdminLogEventActionToggleSignatureProfiles
Sourcefn clone(&self) -> ChannelAdminLogEventActionToggleSignatureProfiles
fn clone(&self) -> ChannelAdminLogEventActionToggleSignatureProfiles
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionToggleSignatureProfiles
impl Deserializable for ChannelAdminLogEventActionToggleSignatureProfiles
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionToggleSignatureProfiles> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionToggleSignatureProfiles> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionToggleSignatureProfiles) -> Self
fn from(x: ChannelAdminLogEventActionToggleSignatureProfiles) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionToggleSignatureProfiles
impl Identifiable for ChannelAdminLogEventActionToggleSignatureProfiles
Sourceconst CONSTRUCTOR_ID: u32 = 0x60a79c79
const CONSTRUCTOR_ID: u32 = 0x60a79c79
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionToggleSignatureProfiles
impl PartialEq for ChannelAdminLogEventActionToggleSignatureProfiles
Sourcefn eq(&self, other: &ChannelAdminLogEventActionToggleSignatureProfiles) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionToggleSignatureProfiles) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleSignatureProfiles
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleSignatureProfiles
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionToggleSignatureProfiles