pub struct ChannelAdminLogEventActionToggleSignatures {
pub new_value: bool,
}Expand description
channelAdminLogEventActionToggleSignatures
Generated from:
channelAdminLogEventActionToggleSignatures#26ae0971 new_value:Bool = ChannelAdminLogEventActionFields
new_value: boolTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionToggleSignatures
impl Clone for ChannelAdminLogEventActionToggleSignatures
Sourcefn clone(&self) -> ChannelAdminLogEventActionToggleSignatures
fn clone(&self) -> ChannelAdminLogEventActionToggleSignatures
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionToggleSignatures
impl Deserializable for ChannelAdminLogEventActionToggleSignatures
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionToggleSignatures> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionToggleSignatures> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionToggleSignatures) -> Self
fn from(x: ChannelAdminLogEventActionToggleSignatures) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionToggleSignatures
impl Identifiable for ChannelAdminLogEventActionToggleSignatures
Sourceconst CONSTRUCTOR_ID: u32 = 0x26ae0971
const CONSTRUCTOR_ID: u32 = 0x26ae0971
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionToggleSignatures
impl PartialEq for ChannelAdminLogEventActionToggleSignatures
Sourcefn eq(&self, other: &ChannelAdminLogEventActionToggleSignatures) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionToggleSignatures) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleSignatures
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleSignatures
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionToggleSignatures