pub struct ChannelAdminLogEventActionToggleSlowMode {
pub prev_value: i32,
pub new_value: i32,
}Expand description
channelAdminLogEventActionToggleSlowMode
Generated from:
channelAdminLogEventActionToggleSlowMode#53909779 prev_value:int new_value:int = ChannelAdminLogEventActionFields
prev_value: i32new_value: i32Trait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionToggleSlowMode
impl Clone for ChannelAdminLogEventActionToggleSlowMode
Sourcefn clone(&self) -> ChannelAdminLogEventActionToggleSlowMode
fn clone(&self) -> ChannelAdminLogEventActionToggleSlowMode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionToggleSlowMode
impl Deserializable for ChannelAdminLogEventActionToggleSlowMode
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionToggleSlowMode> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionToggleSlowMode> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionToggleSlowMode) -> Self
fn from(x: ChannelAdminLogEventActionToggleSlowMode) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionToggleSlowMode
impl Identifiable for ChannelAdminLogEventActionToggleSlowMode
Sourceconst CONSTRUCTOR_ID: u32 = 0x53909779
const CONSTRUCTOR_ID: u32 = 0x53909779
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionToggleSlowMode
impl PartialEq for ChannelAdminLogEventActionToggleSlowMode
Sourcefn eq(&self, other: &ChannelAdminLogEventActionToggleSlowMode) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionToggleSlowMode) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleSlowMode
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionToggleSlowMode
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionToggleSlowMode