pub struct ChannelAdminLogEventActionUpdatePinned {
pub message: Message,
}Expand description
channelAdminLogEventActionUpdatePinned
Generated from:
channelAdminLogEventActionUpdatePinned#e9e82c18 message:Message = ChannelAdminLogEventActionFields
message: MessageTrait Implementations
Sourceimpl Clone for ChannelAdminLogEventActionUpdatePinned
impl Clone for ChannelAdminLogEventActionUpdatePinned
Sourcefn clone(&self) -> ChannelAdminLogEventActionUpdatePinned
fn clone(&self) -> ChannelAdminLogEventActionUpdatePinned
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for ChannelAdminLogEventActionUpdatePinned
impl Deserializable for ChannelAdminLogEventActionUpdatePinned
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<ChannelAdminLogEventActionUpdatePinned> for ChannelAdminLogEventAction
impl From<ChannelAdminLogEventActionUpdatePinned> for ChannelAdminLogEventAction
Sourcefn from(x: ChannelAdminLogEventActionUpdatePinned) -> Self
fn from(x: ChannelAdminLogEventActionUpdatePinned) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for ChannelAdminLogEventActionUpdatePinned
impl Identifiable for ChannelAdminLogEventActionUpdatePinned
Sourceconst CONSTRUCTOR_ID: u32 = 0xe9e82c18
const CONSTRUCTOR_ID: u32 = 0xe9e82c18
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for ChannelAdminLogEventActionUpdatePinned
impl PartialEq for ChannelAdminLogEventActionUpdatePinned
Sourcefn eq(&self, other: &ChannelAdminLogEventActionUpdatePinned) -> bool
fn eq(&self, other: &ChannelAdminLogEventActionUpdatePinned) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionUpdatePinned
impl TryFrom<ChannelAdminLogEventAction> for ChannelAdminLogEventActionUpdatePinned
Sourcetype Error = ChannelAdminLogEventAction
type Error = ChannelAdminLogEventAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for ChannelAdminLogEventActionUpdatePinned