pub struct DocumentAttributeCustomEmoji {
pub free: bool,
pub text_color: bool,
pub alt: String,
pub stickerset: InputStickerSet,
}Expand description
Generated from:
documentAttributeCustomEmoji#fd149899 flags:# free:flags.0?true text_color:flags.1?true alt:string stickerset:InputStickerSet = DocumentAttributeFields
free: booltext_color: boolalt: Stringstickerset: InputStickerSetTrait Implementations
Sourceimpl Clone for DocumentAttributeCustomEmoji
impl Clone for DocumentAttributeCustomEmoji
Sourcefn clone(&self) -> DocumentAttributeCustomEmoji
fn clone(&self) -> DocumentAttributeCustomEmoji
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DocumentAttributeCustomEmoji
impl Debug for DocumentAttributeCustomEmoji
Sourceimpl Deserializable for DocumentAttributeCustomEmoji
impl Deserializable for DocumentAttributeCustomEmoji
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<DocumentAttributeCustomEmoji> for DocumentAttribute
impl From<DocumentAttributeCustomEmoji> for DocumentAttribute
Sourcefn from(x: DocumentAttributeCustomEmoji) -> Self
fn from(x: DocumentAttributeCustomEmoji) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for DocumentAttributeCustomEmoji
impl Identifiable for DocumentAttributeCustomEmoji
Sourceconst CONSTRUCTOR_ID: u32 = 0xfd149899
const CONSTRUCTOR_ID: u32 = 0xfd149899
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for DocumentAttributeCustomEmoji
impl PartialEq for DocumentAttributeCustomEmoji
Sourcefn eq(&self, other: &DocumentAttributeCustomEmoji) -> bool
fn eq(&self, other: &DocumentAttributeCustomEmoji) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<DocumentAttribute> for DocumentAttributeCustomEmoji
impl TryFrom<DocumentAttribute> for DocumentAttributeCustomEmoji
Sourcetype Error = DocumentAttribute
type Error = DocumentAttribute
The type returned in the event of a conversion error.
impl StructuralPartialEq for DocumentAttributeCustomEmoji