pub struct EmailVerifyPurposeLoginSetup {
pub phone_number: String,
pub phone_code_hash: String,
}Expand description
Generated from:
emailVerifyPurposeLoginSetup#4345be73 phone_number:string phone_code_hash:string = EmailVerifyPurposeFields
phone_number: Stringphone_code_hash: StringTrait Implementations
Sourceimpl Clone for EmailVerifyPurposeLoginSetup
impl Clone for EmailVerifyPurposeLoginSetup
Sourcefn clone(&self) -> EmailVerifyPurposeLoginSetup
fn clone(&self) -> EmailVerifyPurposeLoginSetup
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmailVerifyPurposeLoginSetup
impl Debug for EmailVerifyPurposeLoginSetup
Sourceimpl Deserializable for EmailVerifyPurposeLoginSetup
impl Deserializable for EmailVerifyPurposeLoginSetup
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<EmailVerifyPurposeLoginSetup> for EmailVerifyPurpose
impl From<EmailVerifyPurposeLoginSetup> for EmailVerifyPurpose
Sourcefn from(x: EmailVerifyPurposeLoginSetup) -> Self
fn from(x: EmailVerifyPurposeLoginSetup) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for EmailVerifyPurposeLoginSetup
impl Identifiable for EmailVerifyPurposeLoginSetup
Sourceconst CONSTRUCTOR_ID: u32 = 0x4345be73
const CONSTRUCTOR_ID: u32 = 0x4345be73
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for EmailVerifyPurposeLoginSetup
impl PartialEq for EmailVerifyPurposeLoginSetup
Sourcefn eq(&self, other: &EmailVerifyPurposeLoginSetup) -> bool
fn eq(&self, other: &EmailVerifyPurposeLoginSetup) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<EmailVerifyPurpose> for EmailVerifyPurposeLoginSetup
impl TryFrom<EmailVerifyPurpose> for EmailVerifyPurposeLoginSetup
Sourcetype Error = EmailVerifyPurpose
type Error = EmailVerifyPurpose
The type returned in the event of a conversion error.
impl StructuralPartialEq for EmailVerifyPurposeLoginSetup