pub struct GroupCallParticipantVideoSourceGroup {
pub semantics: String,
pub sources: Vec<i32>,
}Expand description
groupCallParticipantVideoSourceGroup
Generated from:
groupCallParticipantVideoSourceGroup#dcb118b7 semantics:string sources:Vector<int> = GroupCallParticipantVideoSourceGroupFields
semantics: Stringsources: Vec<i32>Trait Implementations
Sourceimpl Clone for GroupCallParticipantVideoSourceGroup
impl Clone for GroupCallParticipantVideoSourceGroup
Sourcefn clone(&self) -> GroupCallParticipantVideoSourceGroup
fn clone(&self) -> GroupCallParticipantVideoSourceGroup
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for GroupCallParticipantVideoSourceGroup
impl Deserializable for GroupCallParticipantVideoSourceGroup
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<GroupCallParticipantVideoSourceGroup> for GroupCallParticipantVideoSourceGroup
impl From<GroupCallParticipantVideoSourceGroup> for GroupCallParticipantVideoSourceGroup
Sourcefn from(x: GroupCallParticipantVideoSourceGroup) -> Self
fn from(x: GroupCallParticipantVideoSourceGroup) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for GroupCallParticipantVideoSourceGroup
impl Identifiable for GroupCallParticipantVideoSourceGroup
Sourceconst CONSTRUCTOR_ID: u32 = 0xdcb118b7
const CONSTRUCTOR_ID: u32 = 0xdcb118b7
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for GroupCallParticipantVideoSourceGroup
impl PartialEq for GroupCallParticipantVideoSourceGroup
Sourcefn eq(&self, other: &GroupCallParticipantVideoSourceGroup) -> bool
fn eq(&self, other: &GroupCallParticipantVideoSourceGroup) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<GroupCallParticipantVideoSourceGroup> for GroupCallParticipantVideoSourceGroup
impl TryFrom<GroupCallParticipantVideoSourceGroup> for GroupCallParticipantVideoSourceGroup
Sourcetype Error = GroupCallParticipantVideoSourceGroup
type Error = GroupCallParticipantVideoSourceGroup
The type returned in the event of a conversion error.
impl StructuralPartialEq for GroupCallParticipantVideoSourceGroup