pub struct InputBotInlineMessageMediaGeo {
pub geo_point: InputGeoPoint,
pub heading: Option<i32>,
pub period: Option<i32>,
pub proximity_notification_radius: Option<i32>,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
Generated from:
inputBotInlineMessageMediaGeo#96929a85 flags:# geo_point:InputGeoPoint heading:flags.0?int period:flags.1?int proximity_notification_radius:flags.3?int reply_markup:flags.2?ReplyMarkup = InputBotInlineMessageFields
geo_point: InputGeoPointheading: Option<i32>period: Option<i32>proximity_notification_radius: Option<i32>reply_markup: Option<ReplyMarkup>Trait Implementations
Sourceimpl Clone for InputBotInlineMessageMediaGeo
impl Clone for InputBotInlineMessageMediaGeo
Sourcefn clone(&self) -> InputBotInlineMessageMediaGeo
fn clone(&self) -> InputBotInlineMessageMediaGeo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputBotInlineMessageMediaGeo
impl Deserializable for InputBotInlineMessageMediaGeo
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputBotInlineMessageMediaGeo> for InputBotInlineMessage
impl From<InputBotInlineMessageMediaGeo> for InputBotInlineMessage
Sourcefn from(x: InputBotInlineMessageMediaGeo) -> Self
fn from(x: InputBotInlineMessageMediaGeo) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputBotInlineMessageMediaGeo
impl Identifiable for InputBotInlineMessageMediaGeo
Sourceconst CONSTRUCTOR_ID: u32 = 0x96929a85
const CONSTRUCTOR_ID: u32 = 0x96929a85
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputBotInlineMessageMediaGeo
impl PartialEq for InputBotInlineMessageMediaGeo
Sourcefn eq(&self, other: &InputBotInlineMessageMediaGeo) -> bool
fn eq(&self, other: &InputBotInlineMessageMediaGeo) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputBotInlineMessage> for InputBotInlineMessageMediaGeo
impl TryFrom<InputBotInlineMessage> for InputBotInlineMessageMediaGeo
Sourcetype Error = InputBotInlineMessage
type Error = InputBotInlineMessage
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputBotInlineMessageMediaGeo