pub struct InputBotInlineMessageMediaVenue {
pub geo_point: InputGeoPoint,
pub title: String,
pub address: String,
pub provider: String,
pub venue_id: String,
pub venue_type: String,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
inputBotInlineMessageMediaVenue
Generated from:
inputBotInlineMessageMediaVenue#417bbf11 flags:# geo_point:InputGeoPoint title:string address:string provider:string venue_id:string venue_type:string reply_markup:flags.2?ReplyMarkup = InputBotInlineMessageFields
geo_point: InputGeoPointtitle: Stringaddress: Stringprovider: Stringvenue_id: Stringvenue_type: Stringreply_markup: Option<ReplyMarkup>Trait Implementations
Sourceimpl Clone for InputBotInlineMessageMediaVenue
impl Clone for InputBotInlineMessageMediaVenue
Sourcefn clone(&self) -> InputBotInlineMessageMediaVenue
fn clone(&self) -> InputBotInlineMessageMediaVenue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputBotInlineMessageMediaVenue
impl Deserializable for InputBotInlineMessageMediaVenue
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputBotInlineMessageMediaVenue> for InputBotInlineMessage
impl From<InputBotInlineMessageMediaVenue> for InputBotInlineMessage
Sourcefn from(x: InputBotInlineMessageMediaVenue) -> Self
fn from(x: InputBotInlineMessageMediaVenue) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputBotInlineMessageMediaVenue
impl Identifiable for InputBotInlineMessageMediaVenue
Sourceconst CONSTRUCTOR_ID: u32 = 0x417bbf11
const CONSTRUCTOR_ID: u32 = 0x417bbf11
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputBotInlineMessageMediaVenue
impl PartialEq for InputBotInlineMessageMediaVenue
Sourcefn eq(&self, other: &InputBotInlineMessageMediaVenue) -> bool
fn eq(&self, other: &InputBotInlineMessageMediaVenue) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputBotInlineMessage> for InputBotInlineMessageMediaVenue
impl TryFrom<InputBotInlineMessage> for InputBotInlineMessageMediaVenue
Sourcetype Error = InputBotInlineMessage
type Error = InputBotInlineMessage
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputBotInlineMessageMediaVenue