pub struct InputBotInlineMessageMediaWebPage {
pub invert_media: bool,
pub force_large_media: bool,
pub force_small_media: bool,
pub optional: bool,
pub message: String,
pub entities: Option<Vec<MessageEntity>>,
pub url: String,
pub reply_markup: Option<ReplyMarkup>,
}Expand description
inputBotInlineMessageMediaWebPage
Generated from:
inputBotInlineMessageMediaWebPage#bddcc510 flags:# invert_media:flags.3?true force_large_media:flags.4?true force_small_media:flags.5?true optional:flags.6?true message:string entities:flags.1?Vector<MessageEntity> url:string reply_markup:flags.2?ReplyMarkup = InputBotInlineMessageFields
invert_media: boolforce_large_media: boolforce_small_media: booloptional: boolmessage: Stringentities: Option<Vec<MessageEntity>>url: Stringreply_markup: Option<ReplyMarkup>Trait Implementations
Sourceimpl Clone for InputBotInlineMessageMediaWebPage
impl Clone for InputBotInlineMessageMediaWebPage
Sourcefn clone(&self) -> InputBotInlineMessageMediaWebPage
fn clone(&self) -> InputBotInlineMessageMediaWebPage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputBotInlineMessageMediaWebPage
impl Deserializable for InputBotInlineMessageMediaWebPage
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputBotInlineMessageMediaWebPage> for InputBotInlineMessage
impl From<InputBotInlineMessageMediaWebPage> for InputBotInlineMessage
Sourcefn from(x: InputBotInlineMessageMediaWebPage) -> Self
fn from(x: InputBotInlineMessageMediaWebPage) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputBotInlineMessageMediaWebPage
impl Identifiable for InputBotInlineMessageMediaWebPage
Sourceconst CONSTRUCTOR_ID: u32 = 0xbddcc510
const CONSTRUCTOR_ID: u32 = 0xbddcc510
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputBotInlineMessageMediaWebPage
impl PartialEq for InputBotInlineMessageMediaWebPage
Sourcefn eq(&self, other: &InputBotInlineMessageMediaWebPage) -> bool
fn eq(&self, other: &InputBotInlineMessageMediaWebPage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputBotInlineMessage> for InputBotInlineMessageMediaWebPage
impl TryFrom<InputBotInlineMessage> for InputBotInlineMessageMediaWebPage
Sourcetype Error = InputBotInlineMessage
type Error = InputBotInlineMessage
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputBotInlineMessageMediaWebPage