pub struct InputBusinessGreetingMessage {
pub shortcut_id: i32,
pub recipients: InputBusinessRecipients,
pub no_activity_days: i32,
}Expand description
Generated from:
inputBusinessGreetingMessage#194cb3b shortcut_id:int recipients:InputBusinessRecipients no_activity_days:int = InputBusinessGreetingMessageFields
shortcut_id: i32recipients: InputBusinessRecipientsno_activity_days: i32Trait Implementations
Sourceimpl Clone for InputBusinessGreetingMessage
impl Clone for InputBusinessGreetingMessage
Sourcefn clone(&self) -> InputBusinessGreetingMessage
fn clone(&self) -> InputBusinessGreetingMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputBusinessGreetingMessage
impl Debug for InputBusinessGreetingMessage
Sourceimpl Deserializable for InputBusinessGreetingMessage
impl Deserializable for InputBusinessGreetingMessage
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputBusinessGreetingMessage> for InputBusinessGreetingMessage
impl From<InputBusinessGreetingMessage> for InputBusinessGreetingMessage
Sourcefn from(x: InputBusinessGreetingMessage) -> Self
fn from(x: InputBusinessGreetingMessage) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputBusinessGreetingMessage
impl Identifiable for InputBusinessGreetingMessage
Sourceconst CONSTRUCTOR_ID: u32 = 0x0194cb3b
const CONSTRUCTOR_ID: u32 = 0x0194cb3b
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputBusinessGreetingMessage
impl PartialEq for InputBusinessGreetingMessage
Sourcefn eq(&self, other: &InputBusinessGreetingMessage) -> bool
fn eq(&self, other: &InputBusinessGreetingMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputBusinessGreetingMessage> for InputBusinessGreetingMessage
impl TryFrom<InputBusinessGreetingMessage> for InputBusinessGreetingMessage
Sourcetype Error = InputBusinessGreetingMessage
type Error = InputBusinessGreetingMessage
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputBusinessGreetingMessage