pub struct InputInvoicePremiumGiftStars {
pub user_id: InputUser,
pub months: i32,
pub message: Option<TextWithEntities>,
}Expand description
Generated from:
inputInvoicePremiumGiftStars#dabab2ef flags:# user_id:InputUser months:int message:flags.0?TextWithEntities = InputInvoiceFields
user_id: InputUsermonths: i32message: Option<TextWithEntities>Trait Implementations
Sourceimpl Clone for InputInvoicePremiumGiftStars
impl Clone for InputInvoicePremiumGiftStars
Sourcefn clone(&self) -> InputInvoicePremiumGiftStars
fn clone(&self) -> InputInvoicePremiumGiftStars
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputInvoicePremiumGiftStars
impl Debug for InputInvoicePremiumGiftStars
Sourceimpl Deserializable for InputInvoicePremiumGiftStars
impl Deserializable for InputInvoicePremiumGiftStars
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputInvoicePremiumGiftStars> for InputInvoice
impl From<InputInvoicePremiumGiftStars> for InputInvoice
Sourcefn from(x: InputInvoicePremiumGiftStars) -> Self
fn from(x: InputInvoicePremiumGiftStars) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputInvoicePremiumGiftStars
impl Identifiable for InputInvoicePremiumGiftStars
Sourceconst CONSTRUCTOR_ID: u32 = 0xdabab2ef
const CONSTRUCTOR_ID: u32 = 0xdabab2ef
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputInvoicePremiumGiftStars
impl PartialEq for InputInvoicePremiumGiftStars
Sourcefn eq(&self, other: &InputInvoicePremiumGiftStars) -> bool
fn eq(&self, other: &InputInvoicePremiumGiftStars) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputInvoice> for InputInvoicePremiumGiftStars
impl TryFrom<InputInvoice> for InputInvoicePremiumGiftStars
Sourcetype Error = InputInvoice
type Error = InputInvoice
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputInvoicePremiumGiftStars