pub struct InputKeyboardButtonRequestPeer {
pub name_requested: bool,
pub username_requested: bool,
pub photo_requested: bool,
pub style: Option<KeyboardButtonStyle>,
pub text: String,
pub button_id: i32,
pub peer_type: RequestPeerType,
pub max_quantity: i32,
}Expand description
inputKeyboardButtonRequestPeer
Generated from:
inputKeyboardButtonRequestPeer#2b78156 flags:# name_requested:flags.0?true username_requested:flags.1?true photo_requested:flags.2?true style:flags.10?KeyboardButtonStyle text:string button_id:int peer_type:RequestPeerType max_quantity:int = KeyboardButtonFields
name_requested: boolusername_requested: boolphoto_requested: boolstyle: Option<KeyboardButtonStyle>text: Stringpeer_type: RequestPeerTypemax_quantity: i32Trait Implementations
Sourceimpl Clone for InputKeyboardButtonRequestPeer
impl Clone for InputKeyboardButtonRequestPeer
Sourcefn clone(&self) -> InputKeyboardButtonRequestPeer
fn clone(&self) -> InputKeyboardButtonRequestPeer
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputKeyboardButtonRequestPeer
impl Deserializable for InputKeyboardButtonRequestPeer
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputKeyboardButtonRequestPeer> for KeyboardButton
impl From<InputKeyboardButtonRequestPeer> for KeyboardButton
Sourcefn from(x: InputKeyboardButtonRequestPeer) -> Self
fn from(x: InputKeyboardButtonRequestPeer) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputKeyboardButtonRequestPeer
impl Identifiable for InputKeyboardButtonRequestPeer
Sourceconst CONSTRUCTOR_ID: u32 = 0x02b78156
const CONSTRUCTOR_ID: u32 = 0x02b78156
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputKeyboardButtonRequestPeer
impl PartialEq for InputKeyboardButtonRequestPeer
Sourcefn eq(&self, other: &InputKeyboardButtonRequestPeer) -> bool
fn eq(&self, other: &InputKeyboardButtonRequestPeer) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<KeyboardButton> for InputKeyboardButtonRequestPeer
impl TryFrom<KeyboardButton> for InputKeyboardButtonRequestPeer
Sourcetype Error = KeyboardButton
type Error = KeyboardButton
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputKeyboardButtonRequestPeer