pub struct InputKeyboardButtonUserProfile {
pub style: Option<KeyboardButtonStyle>,
pub text: String,
pub user_id: InputUser,
}Expand description
inputKeyboardButtonUserProfile
Generated from:
inputKeyboardButtonUserProfile#7d5e07c7 flags:# style:flags.10?KeyboardButtonStyle text:string user_id:InputUser = KeyboardButtonFields
style: Option<KeyboardButtonStyle>text: Stringuser_id: InputUserTrait Implementations
Sourceimpl Clone for InputKeyboardButtonUserProfile
impl Clone for InputKeyboardButtonUserProfile
Sourcefn clone(&self) -> InputKeyboardButtonUserProfile
fn clone(&self) -> InputKeyboardButtonUserProfile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputKeyboardButtonUserProfile
impl Deserializable for InputKeyboardButtonUserProfile
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputKeyboardButtonUserProfile> for KeyboardButton
impl From<InputKeyboardButtonUserProfile> for KeyboardButton
Sourcefn from(x: InputKeyboardButtonUserProfile) -> Self
fn from(x: InputKeyboardButtonUserProfile) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputKeyboardButtonUserProfile
impl Identifiable for InputKeyboardButtonUserProfile
Sourceconst CONSTRUCTOR_ID: u32 = 0x7d5e07c7
const CONSTRUCTOR_ID: u32 = 0x7d5e07c7
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputKeyboardButtonUserProfile
impl PartialEq for InputKeyboardButtonUserProfile
Sourcefn eq(&self, other: &InputKeyboardButtonUserProfile) -> bool
fn eq(&self, other: &InputKeyboardButtonUserProfile) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<KeyboardButton> for InputKeyboardButtonUserProfile
impl TryFrom<KeyboardButton> for InputKeyboardButtonUserProfile
Sourcetype Error = KeyboardButton
type Error = KeyboardButton
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputKeyboardButtonUserProfile