pub struct InputPasskeyCredentialFirebasePnv {
pub pnv_token: String,
}Expand description
inputPasskeyCredentialFirebasePNV
Generated from:
inputPasskeyCredentialFirebasePNV#5b1ccb28 pnv_token:string = InputPasskeyCredentialFields
pnv_token: StringTrait Implementations
Sourceimpl Clone for InputPasskeyCredentialFirebasePnv
impl Clone for InputPasskeyCredentialFirebasePnv
Sourcefn clone(&self) -> InputPasskeyCredentialFirebasePnv
fn clone(&self) -> InputPasskeyCredentialFirebasePnv
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputPasskeyCredentialFirebasePnv
impl Deserializable for InputPasskeyCredentialFirebasePnv
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputPasskeyCredentialFirebasePnv> for InputPasskeyCredential
impl From<InputPasskeyCredentialFirebasePnv> for InputPasskeyCredential
Sourcefn from(x: InputPasskeyCredentialFirebasePnv) -> Self
fn from(x: InputPasskeyCredentialFirebasePnv) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputPasskeyCredentialFirebasePnv
impl Identifiable for InputPasskeyCredentialFirebasePnv
Sourceconst CONSTRUCTOR_ID: u32 = 0x5b1ccb28
const CONSTRUCTOR_ID: u32 = 0x5b1ccb28
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputPasskeyCredentialFirebasePnv
impl PartialEq for InputPasskeyCredentialFirebasePnv
Sourcefn eq(&self, other: &InputPasskeyCredentialFirebasePnv) -> bool
fn eq(&self, other: &InputPasskeyCredentialFirebasePnv) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputPasskeyCredential> for InputPasskeyCredentialFirebasePnv
impl TryFrom<InputPasskeyCredential> for InputPasskeyCredentialFirebasePnv
Sourcetype Error = InputPasskeyCredential
type Error = InputPasskeyCredential
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputPasskeyCredentialFirebasePnv