pub struct InputPasskeyCredentialPublicKey {
pub id: String,
pub raw_id: String,
pub response: InputPasskeyResponse,
}Expand description
inputPasskeyCredentialPublicKey
Generated from:
inputPasskeyCredentialPublicKey#3c27b78f id:string raw_id:string response:InputPasskeyResponse = InputPasskeyCredentialFields
id: Stringraw_id: Stringresponse: InputPasskeyResponseTrait Implementations
Sourceimpl Clone for InputPasskeyCredentialPublicKey
impl Clone for InputPasskeyCredentialPublicKey
Sourcefn clone(&self) -> InputPasskeyCredentialPublicKey
fn clone(&self) -> InputPasskeyCredentialPublicKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputPasskeyCredentialPublicKey
impl Deserializable for InputPasskeyCredentialPublicKey
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputPasskeyCredentialPublicKey> for InputPasskeyCredential
impl From<InputPasskeyCredentialPublicKey> for InputPasskeyCredential
Sourcefn from(x: InputPasskeyCredentialPublicKey) -> Self
fn from(x: InputPasskeyCredentialPublicKey) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputPasskeyCredentialPublicKey
impl Identifiable for InputPasskeyCredentialPublicKey
Sourceconst CONSTRUCTOR_ID: u32 = 0x3c27b78f
const CONSTRUCTOR_ID: u32 = 0x3c27b78f
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputPasskeyCredentialPublicKey
impl PartialEq for InputPasskeyCredentialPublicKey
Sourcefn eq(&self, other: &InputPasskeyCredentialPublicKey) -> bool
fn eq(&self, other: &InputPasskeyCredentialPublicKey) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputPasskeyCredential> for InputPasskeyCredentialPublicKey
impl TryFrom<InputPasskeyCredential> for InputPasskeyCredentialPublicKey
Sourcetype Error = InputPasskeyCredential
type Error = InputPasskeyCredential
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputPasskeyCredentialPublicKey