pub struct InputPaymentCredentialsApplePay {
pub payment_data: DataJson,
}Expand description
inputPaymentCredentialsApplePay
Generated from:
inputPaymentCredentialsApplePay#aa1c39f payment_data:DataJSON = InputPaymentCredentialsFields
payment_data: DataJsonTrait Implementations
Sourceimpl Clone for InputPaymentCredentialsApplePay
impl Clone for InputPaymentCredentialsApplePay
Sourcefn clone(&self) -> InputPaymentCredentialsApplePay
fn clone(&self) -> InputPaymentCredentialsApplePay
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputPaymentCredentialsApplePay
impl Deserializable for InputPaymentCredentialsApplePay
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputPaymentCredentialsApplePay> for InputPaymentCredentials
impl From<InputPaymentCredentialsApplePay> for InputPaymentCredentials
Sourcefn from(x: InputPaymentCredentialsApplePay) -> Self
fn from(x: InputPaymentCredentialsApplePay) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputPaymentCredentialsApplePay
impl Identifiable for InputPaymentCredentialsApplePay
Sourceconst CONSTRUCTOR_ID: u32 = 0x0aa1c39f
const CONSTRUCTOR_ID: u32 = 0x0aa1c39f
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputPaymentCredentialsApplePay
impl PartialEq for InputPaymentCredentialsApplePay
Sourcefn eq(&self, other: &InputPaymentCredentialsApplePay) -> bool
fn eq(&self, other: &InputPaymentCredentialsApplePay) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputPaymentCredentials> for InputPaymentCredentialsApplePay
impl TryFrom<InputPaymentCredentials> for InputPaymentCredentialsApplePay
Sourcetype Error = InputPaymentCredentials
type Error = InputPaymentCredentials
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputPaymentCredentialsApplePay