pub struct InputPaymentCredentialsGooglePay {
pub payment_token: DataJson,
}Expand description
inputPaymentCredentialsGooglePay
Generated from:
inputPaymentCredentialsGooglePay#8ac32801 payment_token:DataJSON = InputPaymentCredentialsFields
payment_token: DataJsonTrait Implementations
Sourceimpl Clone for InputPaymentCredentialsGooglePay
impl Clone for InputPaymentCredentialsGooglePay
Sourcefn clone(&self) -> InputPaymentCredentialsGooglePay
fn clone(&self) -> InputPaymentCredentialsGooglePay
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputPaymentCredentialsGooglePay
impl Deserializable for InputPaymentCredentialsGooglePay
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputPaymentCredentialsGooglePay> for InputPaymentCredentials
impl From<InputPaymentCredentialsGooglePay> for InputPaymentCredentials
Sourcefn from(x: InputPaymentCredentialsGooglePay) -> Self
fn from(x: InputPaymentCredentialsGooglePay) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputPaymentCredentialsGooglePay
impl Identifiable for InputPaymentCredentialsGooglePay
Sourceconst CONSTRUCTOR_ID: u32 = 0x8ac32801
const CONSTRUCTOR_ID: u32 = 0x8ac32801
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputPaymentCredentialsGooglePay
impl PartialEq for InputPaymentCredentialsGooglePay
Sourcefn eq(&self, other: &InputPaymentCredentialsGooglePay) -> bool
fn eq(&self, other: &InputPaymentCredentialsGooglePay) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputPaymentCredentials> for InputPaymentCredentialsGooglePay
impl TryFrom<InputPaymentCredentials> for InputPaymentCredentialsGooglePay
Sourcetype Error = InputPaymentCredentials
type Error = InputPaymentCredentials
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputPaymentCredentialsGooglePay