pub struct InputPaymentCredentialsSaved {
pub id: String,
pub tmp_password: Vec<u8>,
}Expand description
Generated from:
inputPaymentCredentialsSaved#c10eb2cf id:string tmp_password:bytes = InputPaymentCredentialsFields
id: Stringtmp_password: Vec<u8>Trait Implementations
Sourceimpl Clone for InputPaymentCredentialsSaved
impl Clone for InputPaymentCredentialsSaved
Sourcefn clone(&self) -> InputPaymentCredentialsSaved
fn clone(&self) -> InputPaymentCredentialsSaved
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputPaymentCredentialsSaved
impl Debug for InputPaymentCredentialsSaved
Sourceimpl Deserializable for InputPaymentCredentialsSaved
impl Deserializable for InputPaymentCredentialsSaved
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputPaymentCredentialsSaved> for InputPaymentCredentials
impl From<InputPaymentCredentialsSaved> for InputPaymentCredentials
Sourcefn from(x: InputPaymentCredentialsSaved) -> Self
fn from(x: InputPaymentCredentialsSaved) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputPaymentCredentialsSaved
impl Identifiable for InputPaymentCredentialsSaved
Sourceconst CONSTRUCTOR_ID: u32 = 0xc10eb2cf
const CONSTRUCTOR_ID: u32 = 0xc10eb2cf
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputPaymentCredentialsSaved
impl PartialEq for InputPaymentCredentialsSaved
Sourcefn eq(&self, other: &InputPaymentCredentialsSaved) -> bool
fn eq(&self, other: &InputPaymentCredentialsSaved) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputPaymentCredentials> for InputPaymentCredentialsSaved
impl TryFrom<InputPaymentCredentials> for InputPaymentCredentialsSaved
Sourcetype Error = InputPaymentCredentials
type Error = InputPaymentCredentials
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputPaymentCredentialsSaved