pub struct InputPhotoLegacyFileLocation {
pub id: i64,
pub access_hash: i64,
pub file_reference: Vec<u8>,
pub volume_id: i64,
pub local_id: i32,
pub secret: i64,
}Expand description
Generated from:
inputPhotoLegacyFileLocation#d83466f3 id:long access_hash:long file_reference:bytes volume_id:long local_id:int secret:long = InputFileLocationFields
id: i64access_hash: i64file_reference: Vec<u8>volume_id: i64local_id: i32secret: i64Trait Implementations
Sourceimpl Clone for InputPhotoLegacyFileLocation
impl Clone for InputPhotoLegacyFileLocation
Sourcefn clone(&self) -> InputPhotoLegacyFileLocation
fn clone(&self) -> InputPhotoLegacyFileLocation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputPhotoLegacyFileLocation
impl Debug for InputPhotoLegacyFileLocation
Sourceimpl Deserializable for InputPhotoLegacyFileLocation
impl Deserializable for InputPhotoLegacyFileLocation
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputPhotoLegacyFileLocation> for InputFileLocation
impl From<InputPhotoLegacyFileLocation> for InputFileLocation
Sourcefn from(x: InputPhotoLegacyFileLocation) -> Self
fn from(x: InputPhotoLegacyFileLocation) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputPhotoLegacyFileLocation
impl Identifiable for InputPhotoLegacyFileLocation
Sourceconst CONSTRUCTOR_ID: u32 = 0xd83466f3
const CONSTRUCTOR_ID: u32 = 0xd83466f3
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputPhotoLegacyFileLocation
impl PartialEq for InputPhotoLegacyFileLocation
Sourcefn eq(&self, other: &InputPhotoLegacyFileLocation) -> bool
fn eq(&self, other: &InputPhotoLegacyFileLocation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputFileLocation> for InputPhotoLegacyFileLocation
impl TryFrom<InputFileLocation> for InputPhotoLegacyFileLocation
Sourcetype Error = InputFileLocation
type Error = InputFileLocation
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputPhotoLegacyFileLocation