pub struct InputPrivacyValueAllowChatParticipants {
pub chats: Vec<i64>,
}Expand description
inputPrivacyValueAllowChatParticipants
Generated from:
inputPrivacyValueAllowChatParticipants#840649cf chats:Vector<long> = InputPrivacyRuleFields
chats: Vec<i64>Trait Implementations
Sourceimpl Clone for InputPrivacyValueAllowChatParticipants
impl Clone for InputPrivacyValueAllowChatParticipants
Sourcefn clone(&self) -> InputPrivacyValueAllowChatParticipants
fn clone(&self) -> InputPrivacyValueAllowChatParticipants
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputPrivacyValueAllowChatParticipants
impl Deserializable for InputPrivacyValueAllowChatParticipants
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputPrivacyValueAllowChatParticipants> for InputPrivacyRule
impl From<InputPrivacyValueAllowChatParticipants> for InputPrivacyRule
Sourcefn from(x: InputPrivacyValueAllowChatParticipants) -> Self
fn from(x: InputPrivacyValueAllowChatParticipants) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputPrivacyValueAllowChatParticipants
impl Identifiable for InputPrivacyValueAllowChatParticipants
Sourceconst CONSTRUCTOR_ID: u32 = 0x840649cf
const CONSTRUCTOR_ID: u32 = 0x840649cf
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputPrivacyValueAllowChatParticipants
impl PartialEq for InputPrivacyValueAllowChatParticipants
Sourcefn eq(&self, other: &InputPrivacyValueAllowChatParticipants) -> bool
fn eq(&self, other: &InputPrivacyValueAllowChatParticipants) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputPrivacyRule> for InputPrivacyValueAllowChatParticipants
impl TryFrom<InputPrivacyRule> for InputPrivacyValueAllowChatParticipants
Sourcetype Error = InputPrivacyRule
type Error = InputPrivacyRule
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputPrivacyValueAllowChatParticipants