pub struct InputPrivacyValueDisallowChatParticipants {
pub chats: Vec<i64>,
}Expand description
inputPrivacyValueDisallowChatParticipants
Generated from:
inputPrivacyValueDisallowChatParticipants#e94f0f86 chats:Vector<long> = InputPrivacyRuleFields
chats: Vec<i64>Trait Implementations
Sourceimpl Clone for InputPrivacyValueDisallowChatParticipants
impl Clone for InputPrivacyValueDisallowChatParticipants
Sourcefn clone(&self) -> InputPrivacyValueDisallowChatParticipants
fn clone(&self) -> InputPrivacyValueDisallowChatParticipants
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputPrivacyValueDisallowChatParticipants
impl Deserializable for InputPrivacyValueDisallowChatParticipants
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputPrivacyValueDisallowChatParticipants> for InputPrivacyRule
impl From<InputPrivacyValueDisallowChatParticipants> for InputPrivacyRule
Sourcefn from(x: InputPrivacyValueDisallowChatParticipants) -> Self
fn from(x: InputPrivacyValueDisallowChatParticipants) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputPrivacyValueDisallowChatParticipants
impl Identifiable for InputPrivacyValueDisallowChatParticipants
Sourceconst CONSTRUCTOR_ID: u32 = 0xe94f0f86
const CONSTRUCTOR_ID: u32 = 0xe94f0f86
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputPrivacyValueDisallowChatParticipants
impl PartialEq for InputPrivacyValueDisallowChatParticipants
Sourcefn eq(&self, other: &InputPrivacyValueDisallowChatParticipants) -> bool
fn eq(&self, other: &InputPrivacyValueDisallowChatParticipants) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputPrivacyRule> for InputPrivacyValueDisallowChatParticipants
impl TryFrom<InputPrivacyRule> for InputPrivacyValueDisallowChatParticipants
Sourcetype Error = InputPrivacyRule
type Error = InputPrivacyRule
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputPrivacyValueDisallowChatParticipants