pub struct InputPrivacyValueDisallowUsers {
pub users: Vec<InputUser>,
}Expand description
inputPrivacyValueDisallowUsers
Generated from:
inputPrivacyValueDisallowUsers#90110467 users:Vector<InputUser> = InputPrivacyRuleFields
users: Vec<InputUser>Trait Implementations
Sourceimpl Clone for InputPrivacyValueDisallowUsers
impl Clone for InputPrivacyValueDisallowUsers
Sourcefn clone(&self) -> InputPrivacyValueDisallowUsers
fn clone(&self) -> InputPrivacyValueDisallowUsers
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputPrivacyValueDisallowUsers
impl Deserializable for InputPrivacyValueDisallowUsers
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputPrivacyValueDisallowUsers> for InputPrivacyRule
impl From<InputPrivacyValueDisallowUsers> for InputPrivacyRule
Sourcefn from(x: InputPrivacyValueDisallowUsers) -> Self
fn from(x: InputPrivacyValueDisallowUsers) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputPrivacyValueDisallowUsers
impl Identifiable for InputPrivacyValueDisallowUsers
Sourceconst CONSTRUCTOR_ID: u32 = 0x90110467
const CONSTRUCTOR_ID: u32 = 0x90110467
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputPrivacyValueDisallowUsers
impl PartialEq for InputPrivacyValueDisallowUsers
Sourcefn eq(&self, other: &InputPrivacyValueDisallowUsers) -> bool
fn eq(&self, other: &InputPrivacyValueDisallowUsers) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputPrivacyRule> for InputPrivacyValueDisallowUsers
impl TryFrom<InputPrivacyRule> for InputPrivacyValueDisallowUsers
Sourcetype Error = InputPrivacyRule
type Error = InputPrivacyRule
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputPrivacyValueDisallowUsers