pub struct InputStorePaymentGiftPremium {
pub user_id: InputUser,
pub currency: String,
pub amount: i64,
}Expand description
Generated from:
inputStorePaymentGiftPremium#616f7fe8 user_id:InputUser currency:string amount:long = InputStorePaymentPurposeFields
user_id: InputUsercurrency: Stringamount: i64Trait Implementations
Sourceimpl Clone for InputStorePaymentGiftPremium
impl Clone for InputStorePaymentGiftPremium
Sourcefn clone(&self) -> InputStorePaymentGiftPremium
fn clone(&self) -> InputStorePaymentGiftPremium
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputStorePaymentGiftPremium
impl Debug for InputStorePaymentGiftPremium
Sourceimpl Deserializable for InputStorePaymentGiftPremium
impl Deserializable for InputStorePaymentGiftPremium
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputStorePaymentGiftPremium> for InputStorePaymentPurpose
impl From<InputStorePaymentGiftPremium> for InputStorePaymentPurpose
Sourcefn from(x: InputStorePaymentGiftPremium) -> Self
fn from(x: InputStorePaymentGiftPremium) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputStorePaymentGiftPremium
impl Identifiable for InputStorePaymentGiftPremium
Sourceconst CONSTRUCTOR_ID: u32 = 0x616f7fe8
const CONSTRUCTOR_ID: u32 = 0x616f7fe8
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputStorePaymentGiftPremium
impl PartialEq for InputStorePaymentGiftPremium
Sourcefn eq(&self, other: &InputStorePaymentGiftPremium) -> bool
fn eq(&self, other: &InputStorePaymentGiftPremium) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputStorePaymentPurpose> for InputStorePaymentGiftPremium
impl TryFrom<InputStorePaymentPurpose> for InputStorePaymentGiftPremium
Sourcetype Error = InputStorePaymentPurpose
type Error = InputStorePaymentPurpose
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputStorePaymentGiftPremium