pub struct InputStorePaymentPremiumGiftCode {
pub users: Vec<InputUser>,
pub boost_peer: Option<InputPeer>,
pub currency: String,
pub amount: i64,
pub message: Option<TextWithEntities>,
}Expand description
inputStorePaymentPremiumGiftCode
Generated from:
inputStorePaymentPremiumGiftCode#fb790393 flags:# users:Vector<InputUser> boost_peer:flags.0?InputPeer currency:string amount:long message:flags.1?TextWithEntities = InputStorePaymentPurposeFields
users: Vec<InputUser>boost_peer: Option<InputPeer>currency: Stringamount: i64message: Option<TextWithEntities>Trait Implementations
Sourceimpl Clone for InputStorePaymentPremiumGiftCode
impl Clone for InputStorePaymentPremiumGiftCode
Sourcefn clone(&self) -> InputStorePaymentPremiumGiftCode
fn clone(&self) -> InputStorePaymentPremiumGiftCode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputStorePaymentPremiumGiftCode
impl Deserializable for InputStorePaymentPremiumGiftCode
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputStorePaymentPremiumGiftCode> for InputStorePaymentPurpose
impl From<InputStorePaymentPremiumGiftCode> for InputStorePaymentPurpose
Sourcefn from(x: InputStorePaymentPremiumGiftCode) -> Self
fn from(x: InputStorePaymentPremiumGiftCode) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputStorePaymentPremiumGiftCode
impl Identifiable for InputStorePaymentPremiumGiftCode
Sourceconst CONSTRUCTOR_ID: u32 = 0xfb790393
const CONSTRUCTOR_ID: u32 = 0xfb790393
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputStorePaymentPremiumGiftCode
impl PartialEq for InputStorePaymentPremiumGiftCode
Sourcefn eq(&self, other: &InputStorePaymentPremiumGiftCode) -> bool
fn eq(&self, other: &InputStorePaymentPremiumGiftCode) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputStorePaymentPurpose> for InputStorePaymentPremiumGiftCode
impl TryFrom<InputStorePaymentPurpose> for InputStorePaymentPremiumGiftCode
Sourcetype Error = InputStorePaymentPurpose
type Error = InputStorePaymentPurpose
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputStorePaymentPremiumGiftCode