pub struct InputStorePaymentPremiumGiveaway {
pub only_new_subscribers: bool,
pub winners_are_visible: bool,
pub boost_peer: InputPeer,
pub additional_peers: Option<Vec<InputPeer>>,
pub countries_iso2: Option<Vec<String>>,
pub prize_description: Option<String>,
pub random_id: i64,
pub until_date: i32,
pub currency: String,
pub amount: i64,
}Expand description
inputStorePaymentPremiumGiveaway
Generated from:
inputStorePaymentPremiumGiveaway#160544ca flags:# only_new_subscribers:flags.0?true winners_are_visible:flags.3?true boost_peer:InputPeer additional_peers:flags.1?Vector<InputPeer> countries_iso2:flags.2?Vector<string> prize_description:flags.4?string random_id:long until_date:int currency:string amount:long = InputStorePaymentPurposeFields
only_new_subscribers: boolwinners_are_visible: boolboost_peer: InputPeeradditional_peers: Option<Vec<InputPeer>>countries_iso2: Option<Vec<String>>prize_description: Option<String>random_id: i64until_date: i32currency: Stringamount: i64Trait Implementations
Sourceimpl Clone for InputStorePaymentPremiumGiveaway
impl Clone for InputStorePaymentPremiumGiveaway
Sourcefn clone(&self) -> InputStorePaymentPremiumGiveaway
fn clone(&self) -> InputStorePaymentPremiumGiveaway
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputStorePaymentPremiumGiveaway
impl Deserializable for InputStorePaymentPremiumGiveaway
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputStorePaymentPremiumGiveaway> for InputStorePaymentPurpose
impl From<InputStorePaymentPremiumGiveaway> for InputStorePaymentPurpose
Sourcefn from(x: InputStorePaymentPremiumGiveaway) -> Self
fn from(x: InputStorePaymentPremiumGiveaway) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputStorePaymentPremiumGiveaway
impl Identifiable for InputStorePaymentPremiumGiveaway
Sourceconst CONSTRUCTOR_ID: u32 = 0x160544ca
const CONSTRUCTOR_ID: u32 = 0x160544ca
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputStorePaymentPremiumGiveaway
impl PartialEq for InputStorePaymentPremiumGiveaway
Sourcefn eq(&self, other: &InputStorePaymentPremiumGiveaway) -> bool
fn eq(&self, other: &InputStorePaymentPremiumGiveaway) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputStorePaymentPurpose> for InputStorePaymentPremiumGiveaway
impl TryFrom<InputStorePaymentPurpose> for InputStorePaymentPremiumGiveaway
Sourcetype Error = InputStorePaymentPurpose
type Error = InputStorePaymentPurpose
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputStorePaymentPremiumGiveaway