pub struct InputStorePaymentPremiumSubscription {
pub restore: bool,
pub upgrade: bool,
}Expand description
inputStorePaymentPremiumSubscription
Generated from:
inputStorePaymentPremiumSubscription#a6751e66 flags:# restore:flags.0?true upgrade:flags.1?true = InputStorePaymentPurposeFields
restore: boolupgrade: boolTrait Implementations
Sourceimpl Clone for InputStorePaymentPremiumSubscription
impl Clone for InputStorePaymentPremiumSubscription
Sourcefn clone(&self) -> InputStorePaymentPremiumSubscription
fn clone(&self) -> InputStorePaymentPremiumSubscription
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputStorePaymentPremiumSubscription
impl Deserializable for InputStorePaymentPremiumSubscription
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputStorePaymentPremiumSubscription> for InputStorePaymentPurpose
impl From<InputStorePaymentPremiumSubscription> for InputStorePaymentPurpose
Sourcefn from(x: InputStorePaymentPremiumSubscription) -> Self
fn from(x: InputStorePaymentPremiumSubscription) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputStorePaymentPremiumSubscription
impl Identifiable for InputStorePaymentPremiumSubscription
Sourceconst CONSTRUCTOR_ID: u32 = 0xa6751e66
const CONSTRUCTOR_ID: u32 = 0xa6751e66
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputStorePaymentPremiumSubscription
impl PartialEq for InputStorePaymentPremiumSubscription
Sourcefn eq(&self, other: &InputStorePaymentPremiumSubscription) -> bool
fn eq(&self, other: &InputStorePaymentPremiumSubscription) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputStorePaymentPurpose> for InputStorePaymentPremiumSubscription
impl TryFrom<InputStorePaymentPurpose> for InputStorePaymentPremiumSubscription
Sourcetype Error = InputStorePaymentPurpose
type Error = InputStorePaymentPurpose
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputStorePaymentPremiumSubscription