pub struct InputStorePaymentStarsGiveaway {
pub only_new_subscribers: bool,
pub winners_are_visible: bool,
pub stars: i64,
pub boost_peer: InputPeer,
pub additional_peers: Option<Vec<InputPeer>>,
pub countries_iso2: Option<Vec<String>>,
pub prize_description: Option<String>,
pub random_id: i64,
pub until_date: i32,
pub currency: String,
pub amount: i64,
pub users: i32,
}Expand description
inputStorePaymentStarsGiveaway
Generated from:
inputStorePaymentStarsGiveaway#751f08fa flags:# only_new_subscribers:flags.0?true winners_are_visible:flags.3?true stars:long boost_peer:InputPeer additional_peers:flags.1?Vector<InputPeer> countries_iso2:flags.2?Vector<string> prize_description:flags.4?string random_id:long until_date:int currency:string amount:long users:int = InputStorePaymentPurposeFields
only_new_subscribers: boolwinners_are_visible: boolstars: i64boost_peer: InputPeeradditional_peers: Option<Vec<InputPeer>>countries_iso2: Option<Vec<String>>prize_description: Option<String>random_id: i64until_date: i32currency: Stringamount: i64users: i32Trait Implementations
Sourceimpl Clone for InputStorePaymentStarsGiveaway
impl Clone for InputStorePaymentStarsGiveaway
Sourcefn clone(&self) -> InputStorePaymentStarsGiveaway
fn clone(&self) -> InputStorePaymentStarsGiveaway
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for InputStorePaymentStarsGiveaway
impl Deserializable for InputStorePaymentStarsGiveaway
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputStorePaymentStarsGiveaway> for InputStorePaymentPurpose
impl From<InputStorePaymentStarsGiveaway> for InputStorePaymentPurpose
Sourcefn from(x: InputStorePaymentStarsGiveaway) -> Self
fn from(x: InputStorePaymentStarsGiveaway) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputStorePaymentStarsGiveaway
impl Identifiable for InputStorePaymentStarsGiveaway
Sourceconst CONSTRUCTOR_ID: u32 = 0x751f08fa
const CONSTRUCTOR_ID: u32 = 0x751f08fa
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputStorePaymentStarsGiveaway
impl PartialEq for InputStorePaymentStarsGiveaway
Sourcefn eq(&self, other: &InputStorePaymentStarsGiveaway) -> bool
fn eq(&self, other: &InputStorePaymentStarsGiveaway) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputStorePaymentPurpose> for InputStorePaymentStarsGiveaway
impl TryFrom<InputStorePaymentPurpose> for InputStorePaymentStarsGiveaway
Sourcetype Error = InputStorePaymentPurpose
type Error = InputStorePaymentPurpose
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputStorePaymentStarsGiveaway