pub struct InputWebFileGeoPointLocation {
pub geo_point: InputGeoPoint,
pub access_hash: i64,
pub w: i32,
pub h: i32,
pub zoom: i32,
pub scale: i32,
}Expand description
Generated from:
inputWebFileGeoPointLocation#9f2221c9 geo_point:InputGeoPoint access_hash:long w:int h:int zoom:int scale:int = InputWebFileLocationFields
geo_point: InputGeoPointaccess_hash: i64w: i32h: i32zoom: i32scale: i32Trait Implementations
Sourceimpl Clone for InputWebFileGeoPointLocation
impl Clone for InputWebFileGeoPointLocation
Sourcefn clone(&self) -> InputWebFileGeoPointLocation
fn clone(&self) -> InputWebFileGeoPointLocation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputWebFileGeoPointLocation
impl Debug for InputWebFileGeoPointLocation
Sourceimpl Deserializable for InputWebFileGeoPointLocation
impl Deserializable for InputWebFileGeoPointLocation
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<InputWebFileGeoPointLocation> for InputWebFileLocation
impl From<InputWebFileGeoPointLocation> for InputWebFileLocation
Sourcefn from(x: InputWebFileGeoPointLocation) -> Self
fn from(x: InputWebFileGeoPointLocation) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for InputWebFileGeoPointLocation
impl Identifiable for InputWebFileGeoPointLocation
Sourceconst CONSTRUCTOR_ID: u32 = 0x9f2221c9
const CONSTRUCTOR_ID: u32 = 0x9f2221c9
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for InputWebFileGeoPointLocation
impl PartialEq for InputWebFileGeoPointLocation
Sourcefn eq(&self, other: &InputWebFileGeoPointLocation) -> bool
fn eq(&self, other: &InputWebFileGeoPointLocation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<InputWebFileLocation> for InputWebFileGeoPointLocation
impl TryFrom<InputWebFileLocation> for InputWebFileGeoPointLocation
Sourcetype Error = InputWebFileLocation
type Error = InputWebFileLocation
The type returned in the event of a conversion error.
impl StructuralPartialEq for InputWebFileGeoPointLocation