pub struct KeyboardButtonRequestGeoLocation {
pub style: Option<KeyboardButtonStyle>,
pub text: String,
}Expand description
keyboardButtonRequestGeoLocation
Generated from:
keyboardButtonRequestGeoLocation#aa40f94d flags:# style:flags.10?KeyboardButtonStyle text:string = KeyboardButtonFields
style: Option<KeyboardButtonStyle>text: StringTrait Implementations
Sourceimpl Clone for KeyboardButtonRequestGeoLocation
impl Clone for KeyboardButtonRequestGeoLocation
Sourcefn clone(&self) -> KeyboardButtonRequestGeoLocation
fn clone(&self) -> KeyboardButtonRequestGeoLocation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for KeyboardButtonRequestGeoLocation
impl Deserializable for KeyboardButtonRequestGeoLocation
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<KeyboardButtonRequestGeoLocation> for KeyboardButton
impl From<KeyboardButtonRequestGeoLocation> for KeyboardButton
Sourcefn from(x: KeyboardButtonRequestGeoLocation) -> Self
fn from(x: KeyboardButtonRequestGeoLocation) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for KeyboardButtonRequestGeoLocation
impl Identifiable for KeyboardButtonRequestGeoLocation
Sourceconst CONSTRUCTOR_ID: u32 = 0xaa40f94d
const CONSTRUCTOR_ID: u32 = 0xaa40f94d
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for KeyboardButtonRequestGeoLocation
impl PartialEq for KeyboardButtonRequestGeoLocation
Sourcefn eq(&self, other: &KeyboardButtonRequestGeoLocation) -> bool
fn eq(&self, other: &KeyboardButtonRequestGeoLocation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<KeyboardButton> for KeyboardButtonRequestGeoLocation
impl TryFrom<KeyboardButton> for KeyboardButtonRequestGeoLocation
Sourcetype Error = KeyboardButton
type Error = KeyboardButton
The type returned in the event of a conversion error.
impl StructuralPartialEq for KeyboardButtonRequestGeoLocation