pub struct MessageActionChannelMigrateFrom {
pub title: String,
pub chat_id: i64,
}Expand description
messageActionChannelMigrateFrom
Generated from:
messageActionChannelMigrateFrom#ea3948e9 title:string chat_id:long = MessageActionFields
title: Stringchat_id: i64Trait Implementations
Sourceimpl Clone for MessageActionChannelMigrateFrom
impl Clone for MessageActionChannelMigrateFrom
Sourcefn clone(&self) -> MessageActionChannelMigrateFrom
fn clone(&self) -> MessageActionChannelMigrateFrom
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionChannelMigrateFrom
impl Deserializable for MessageActionChannelMigrateFrom
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionChannelMigrateFrom> for MessageAction
impl From<MessageActionChannelMigrateFrom> for MessageAction
Sourcefn from(x: MessageActionChannelMigrateFrom) -> Self
fn from(x: MessageActionChannelMigrateFrom) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionChannelMigrateFrom
impl Identifiable for MessageActionChannelMigrateFrom
Sourceconst CONSTRUCTOR_ID: u32 = 0xea3948e9
const CONSTRUCTOR_ID: u32 = 0xea3948e9
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionChannelMigrateFrom
impl PartialEq for MessageActionChannelMigrateFrom
Sourcefn eq(&self, other: &MessageActionChannelMigrateFrom) -> bool
fn eq(&self, other: &MessageActionChannelMigrateFrom) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionChannelMigrateFrom
impl TryFrom<MessageAction> for MessageActionChannelMigrateFrom
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionChannelMigrateFrom