pub struct MessageActionChatJoinedByLink {
pub inviter_id: i64,
}Expand description
Generated from:
messageActionChatJoinedByLink#31224c3 inviter_id:long = MessageActionFields
inviter_id: i64Trait Implementations
Sourceimpl Clone for MessageActionChatJoinedByLink
impl Clone for MessageActionChatJoinedByLink
Sourcefn clone(&self) -> MessageActionChatJoinedByLink
fn clone(&self) -> MessageActionChatJoinedByLink
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionChatJoinedByLink
impl Deserializable for MessageActionChatJoinedByLink
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionChatJoinedByLink> for MessageAction
impl From<MessageActionChatJoinedByLink> for MessageAction
Sourcefn from(x: MessageActionChatJoinedByLink) -> Self
fn from(x: MessageActionChatJoinedByLink) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionChatJoinedByLink
impl Identifiable for MessageActionChatJoinedByLink
Sourceconst CONSTRUCTOR_ID: u32 = 0x031224c3
const CONSTRUCTOR_ID: u32 = 0x031224c3
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionChatJoinedByLink
impl PartialEq for MessageActionChatJoinedByLink
Sourcefn eq(&self, other: &MessageActionChatJoinedByLink) -> bool
fn eq(&self, other: &MessageActionChatJoinedByLink) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionChatJoinedByLink
impl TryFrom<MessageAction> for MessageActionChatJoinedByLink
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionChatJoinedByLink