pub struct MessageActionManagedBotCreated {
pub bot_id: i64,
}Expand description
messageActionManagedBotCreated
Generated from:
messageActionManagedBotCreated#16605e3e bot_id:long = MessageActionFields
bot_id: i64Trait Implementations
Sourceimpl Clone for MessageActionManagedBotCreated
impl Clone for MessageActionManagedBotCreated
Sourcefn clone(&self) -> MessageActionManagedBotCreated
fn clone(&self) -> MessageActionManagedBotCreated
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionManagedBotCreated
impl Deserializable for MessageActionManagedBotCreated
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionManagedBotCreated> for MessageAction
impl From<MessageActionManagedBotCreated> for MessageAction
Sourcefn from(x: MessageActionManagedBotCreated) -> Self
fn from(x: MessageActionManagedBotCreated) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionManagedBotCreated
impl Identifiable for MessageActionManagedBotCreated
Sourceconst CONSTRUCTOR_ID: u32 = 0x16605e3e
const CONSTRUCTOR_ID: u32 = 0x16605e3e
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionManagedBotCreated
impl PartialEq for MessageActionManagedBotCreated
Sourcefn eq(&self, other: &MessageActionManagedBotCreated) -> bool
fn eq(&self, other: &MessageActionManagedBotCreated) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionManagedBotCreated
impl TryFrom<MessageAction> for MessageActionManagedBotCreated
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionManagedBotCreated