pub struct MessageActionNewCreatorPending {
pub new_creator_id: i64,
}Expand description
messageActionNewCreatorPending
Generated from:
messageActionNewCreatorPending#b07ed085 new_creator_id:long = MessageActionFields
new_creator_id: i64Trait Implementations
Sourceimpl Clone for MessageActionNewCreatorPending
impl Clone for MessageActionNewCreatorPending
Sourcefn clone(&self) -> MessageActionNewCreatorPending
fn clone(&self) -> MessageActionNewCreatorPending
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionNewCreatorPending
impl Deserializable for MessageActionNewCreatorPending
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionNewCreatorPending> for MessageAction
impl From<MessageActionNewCreatorPending> for MessageAction
Sourcefn from(x: MessageActionNewCreatorPending) -> Self
fn from(x: MessageActionNewCreatorPending) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionNewCreatorPending
impl Identifiable for MessageActionNewCreatorPending
Sourceconst CONSTRUCTOR_ID: u32 = 0xb07ed085
const CONSTRUCTOR_ID: u32 = 0xb07ed085
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionNewCreatorPending
impl PartialEq for MessageActionNewCreatorPending
Sourcefn eq(&self, other: &MessageActionNewCreatorPending) -> bool
fn eq(&self, other: &MessageActionNewCreatorPending) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionNewCreatorPending
impl TryFrom<MessageAction> for MessageActionNewCreatorPending
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionNewCreatorPending