pub struct MessageActionNoForwardsToggle {
pub prev_value: bool,
pub new_value: bool,
}Expand description
Generated from:
messageActionNoForwardsToggle#bf7d6572 prev_value:Bool new_value:Bool = MessageActionFields
prev_value: boolnew_value: boolTrait Implementations
Sourceimpl Clone for MessageActionNoForwardsToggle
impl Clone for MessageActionNoForwardsToggle
Sourcefn clone(&self) -> MessageActionNoForwardsToggle
fn clone(&self) -> MessageActionNoForwardsToggle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionNoForwardsToggle
impl Deserializable for MessageActionNoForwardsToggle
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionNoForwardsToggle> for MessageAction
impl From<MessageActionNoForwardsToggle> for MessageAction
Sourcefn from(x: MessageActionNoForwardsToggle) -> Self
fn from(x: MessageActionNoForwardsToggle) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionNoForwardsToggle
impl Identifiable for MessageActionNoForwardsToggle
Sourceconst CONSTRUCTOR_ID: u32 = 0xbf7d6572
const CONSTRUCTOR_ID: u32 = 0xbf7d6572
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionNoForwardsToggle
impl PartialEq for MessageActionNoForwardsToggle
Sourcefn eq(&self, other: &MessageActionNoForwardsToggle) -> bool
fn eq(&self, other: &MessageActionNoForwardsToggle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionNoForwardsToggle
impl TryFrom<MessageAction> for MessageActionNoForwardsToggle
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionNoForwardsToggle