pub struct MessageActionPaidMessagesPrice {
pub broadcast_messages_allowed: bool,
pub stars: i64,
}Expand description
messageActionPaidMessagesPrice
Generated from:
messageActionPaidMessagesPrice#84b88578 flags:# broadcast_messages_allowed:flags.0?true stars:long = MessageActionFields
broadcast_messages_allowed: boolstars: i64Trait Implementations
Sourceimpl Clone for MessageActionPaidMessagesPrice
impl Clone for MessageActionPaidMessagesPrice
Sourcefn clone(&self) -> MessageActionPaidMessagesPrice
fn clone(&self) -> MessageActionPaidMessagesPrice
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionPaidMessagesPrice
impl Deserializable for MessageActionPaidMessagesPrice
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionPaidMessagesPrice> for MessageAction
impl From<MessageActionPaidMessagesPrice> for MessageAction
Sourcefn from(x: MessageActionPaidMessagesPrice) -> Self
fn from(x: MessageActionPaidMessagesPrice) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionPaidMessagesPrice
impl Identifiable for MessageActionPaidMessagesPrice
Sourceconst CONSTRUCTOR_ID: u32 = 0x84b88578
const CONSTRUCTOR_ID: u32 = 0x84b88578
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionPaidMessagesPrice
impl PartialEq for MessageActionPaidMessagesPrice
Sourcefn eq(&self, other: &MessageActionPaidMessagesPrice) -> bool
fn eq(&self, other: &MessageActionPaidMessagesPrice) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionPaidMessagesPrice
impl TryFrom<MessageAction> for MessageActionPaidMessagesPrice
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionPaidMessagesPrice