pub struct MessageActionPaidMessagesRefunded {
pub count: i32,
pub stars: i64,
}Expand description
messageActionPaidMessagesRefunded
Generated from:
messageActionPaidMessagesRefunded#ac1f1fcd count:int stars:long = MessageActionFields
count: i32stars: i64Trait Implementations
Sourceimpl Clone for MessageActionPaidMessagesRefunded
impl Clone for MessageActionPaidMessagesRefunded
Sourcefn clone(&self) -> MessageActionPaidMessagesRefunded
fn clone(&self) -> MessageActionPaidMessagesRefunded
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionPaidMessagesRefunded
impl Deserializable for MessageActionPaidMessagesRefunded
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionPaidMessagesRefunded> for MessageAction
impl From<MessageActionPaidMessagesRefunded> for MessageAction
Sourcefn from(x: MessageActionPaidMessagesRefunded) -> Self
fn from(x: MessageActionPaidMessagesRefunded) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionPaidMessagesRefunded
impl Identifiable for MessageActionPaidMessagesRefunded
Sourceconst CONSTRUCTOR_ID: u32 = 0xac1f1fcd
const CONSTRUCTOR_ID: u32 = 0xac1f1fcd
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionPaidMessagesRefunded
impl PartialEq for MessageActionPaidMessagesRefunded
Sourcefn eq(&self, other: &MessageActionPaidMessagesRefunded) -> bool
fn eq(&self, other: &MessageActionPaidMessagesRefunded) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionPaidMessagesRefunded
impl TryFrom<MessageAction> for MessageActionPaidMessagesRefunded
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionPaidMessagesRefunded