pub struct MessageActionPaymentRefunded {
pub peer: Peer,
pub currency: String,
pub total_amount: i64,
pub payload: Option<Vec<u8>>,
pub charge: PaymentCharge,
}Expand description
Generated from:
messageActionPaymentRefunded#41b3e202 flags:# peer:Peer currency:string total_amount:long payload:flags.0?bytes charge:PaymentCharge = MessageActionFields
peer: Peercurrency: Stringtotal_amount: i64payload: Option<Vec<u8>>charge: PaymentChargeTrait Implementations
Sourceimpl Clone for MessageActionPaymentRefunded
impl Clone for MessageActionPaymentRefunded
Sourcefn clone(&self) -> MessageActionPaymentRefunded
fn clone(&self) -> MessageActionPaymentRefunded
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageActionPaymentRefunded
impl Debug for MessageActionPaymentRefunded
Sourceimpl Deserializable for MessageActionPaymentRefunded
impl Deserializable for MessageActionPaymentRefunded
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionPaymentRefunded> for MessageAction
impl From<MessageActionPaymentRefunded> for MessageAction
Sourcefn from(x: MessageActionPaymentRefunded) -> Self
fn from(x: MessageActionPaymentRefunded) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionPaymentRefunded
impl Identifiable for MessageActionPaymentRefunded
Sourceconst CONSTRUCTOR_ID: u32 = 0x41b3e202
const CONSTRUCTOR_ID: u32 = 0x41b3e202
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionPaymentRefunded
impl PartialEq for MessageActionPaymentRefunded
Sourcefn eq(&self, other: &MessageActionPaymentRefunded) -> bool
fn eq(&self, other: &MessageActionPaymentRefunded) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionPaymentRefunded
impl TryFrom<MessageAction> for MessageActionPaymentRefunded
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionPaymentRefunded