pub struct MessageActionSecureValuesSent {
pub types: Vec<SecureValueType>,
}Expand description
Generated from:
messageActionSecureValuesSent#d95c6154 types:Vector<SecureValueType> = MessageActionFields
types: Vec<SecureValueType>Trait Implementations
Sourceimpl Clone for MessageActionSecureValuesSent
impl Clone for MessageActionSecureValuesSent
Sourcefn clone(&self) -> MessageActionSecureValuesSent
fn clone(&self) -> MessageActionSecureValuesSent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionSecureValuesSent
impl Deserializable for MessageActionSecureValuesSent
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionSecureValuesSent> for MessageAction
impl From<MessageActionSecureValuesSent> for MessageAction
Sourcefn from(x: MessageActionSecureValuesSent) -> Self
fn from(x: MessageActionSecureValuesSent) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionSecureValuesSent
impl Identifiable for MessageActionSecureValuesSent
Sourceconst CONSTRUCTOR_ID: u32 = 0xd95c6154
const CONSTRUCTOR_ID: u32 = 0xd95c6154
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionSecureValuesSent
impl PartialEq for MessageActionSecureValuesSent
Sourcefn eq(&self, other: &MessageActionSecureValuesSent) -> bool
fn eq(&self, other: &MessageActionSecureValuesSent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionSecureValuesSent
impl TryFrom<MessageAction> for MessageActionSecureValuesSent
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionSecureValuesSent