pub struct MessageActionSecureValuesSentMe {
pub values: Vec<SecureValue>,
pub credentials: SecureCredentialsEncrypted,
}Expand description
messageActionSecureValuesSentMe
Generated from:
messageActionSecureValuesSentMe#1b287353 values:Vector<SecureValue> credentials:SecureCredentialsEncrypted = MessageActionFields
values: Vec<SecureValue>credentials: SecureCredentialsEncryptedTrait Implementations
Sourceimpl Clone for MessageActionSecureValuesSentMe
impl Clone for MessageActionSecureValuesSentMe
Sourcefn clone(&self) -> MessageActionSecureValuesSentMe
fn clone(&self) -> MessageActionSecureValuesSentMe
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionSecureValuesSentMe
impl Deserializable for MessageActionSecureValuesSentMe
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionSecureValuesSentMe> for MessageAction
impl From<MessageActionSecureValuesSentMe> for MessageAction
Sourcefn from(x: MessageActionSecureValuesSentMe) -> Self
fn from(x: MessageActionSecureValuesSentMe) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionSecureValuesSentMe
impl Identifiable for MessageActionSecureValuesSentMe
Sourceconst CONSTRUCTOR_ID: u32 = 0x1b287353
const CONSTRUCTOR_ID: u32 = 0x1b287353
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionSecureValuesSentMe
impl PartialEq for MessageActionSecureValuesSentMe
Sourcefn eq(&self, other: &MessageActionSecureValuesSentMe) -> bool
fn eq(&self, other: &MessageActionSecureValuesSentMe) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionSecureValuesSentMe
impl TryFrom<MessageAction> for MessageActionSecureValuesSentMe
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionSecureValuesSentMe