pub struct MessageActionSetChatWallPaper {
pub same: bool,
pub for_both: bool,
pub wallpaper: WallPaper,
}Expand description
Generated from:
messageActionSetChatWallPaper#5060a3f4 flags:# same:flags.0?true for_both:flags.1?true wallpaper:WallPaper = MessageActionFields
same: boolfor_both: boolwallpaper: WallPaperTrait Implementations
Sourceimpl Clone for MessageActionSetChatWallPaper
impl Clone for MessageActionSetChatWallPaper
Sourcefn clone(&self) -> MessageActionSetChatWallPaper
fn clone(&self) -> MessageActionSetChatWallPaper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionSetChatWallPaper
impl Deserializable for MessageActionSetChatWallPaper
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionSetChatWallPaper> for MessageAction
impl From<MessageActionSetChatWallPaper> for MessageAction
Sourcefn from(x: MessageActionSetChatWallPaper) -> Self
fn from(x: MessageActionSetChatWallPaper) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionSetChatWallPaper
impl Identifiable for MessageActionSetChatWallPaper
Sourceconst CONSTRUCTOR_ID: u32 = 0x5060a3f4
const CONSTRUCTOR_ID: u32 = 0x5060a3f4
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionSetChatWallPaper
impl PartialEq for MessageActionSetChatWallPaper
Sourcefn eq(&self, other: &MessageActionSetChatWallPaper) -> bool
fn eq(&self, other: &MessageActionSetChatWallPaper) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionSetChatWallPaper
impl TryFrom<MessageAction> for MessageActionSetChatWallPaper
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionSetChatWallPaper