pub struct MessageActionStarGiftPurchaseOfferDeclined {
pub expired: bool,
pub gift: StarGift,
pub price: StarsAmount,
}Expand description
messageActionStarGiftPurchaseOfferDeclined
Generated from:
messageActionStarGiftPurchaseOfferDeclined#73ada76b flags:# expired:flags.0?true gift:StarGift price:StarsAmount = MessageActionFields
expired: boolgift: StarGiftprice: StarsAmountTrait Implementations
Sourceimpl Clone for MessageActionStarGiftPurchaseOfferDeclined
impl Clone for MessageActionStarGiftPurchaseOfferDeclined
Sourcefn clone(&self) -> MessageActionStarGiftPurchaseOfferDeclined
fn clone(&self) -> MessageActionStarGiftPurchaseOfferDeclined
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionStarGiftPurchaseOfferDeclined
impl Deserializable for MessageActionStarGiftPurchaseOfferDeclined
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionStarGiftPurchaseOfferDeclined> for MessageAction
impl From<MessageActionStarGiftPurchaseOfferDeclined> for MessageAction
Sourcefn from(x: MessageActionStarGiftPurchaseOfferDeclined) -> Self
fn from(x: MessageActionStarGiftPurchaseOfferDeclined) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionStarGiftPurchaseOfferDeclined
impl Identifiable for MessageActionStarGiftPurchaseOfferDeclined
Sourceconst CONSTRUCTOR_ID: u32 = 0x73ada76b
const CONSTRUCTOR_ID: u32 = 0x73ada76b
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionStarGiftPurchaseOfferDeclined
impl PartialEq for MessageActionStarGiftPurchaseOfferDeclined
Sourcefn eq(&self, other: &MessageActionStarGiftPurchaseOfferDeclined) -> bool
fn eq(&self, other: &MessageActionStarGiftPurchaseOfferDeclined) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionStarGiftPurchaseOfferDeclined
impl TryFrom<MessageAction> for MessageActionStarGiftPurchaseOfferDeclined
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionStarGiftPurchaseOfferDeclined