pub struct MessageActionSuggestedPostRefund {
pub payer_initiated: bool,
}Expand description
messageActionSuggestedPostRefund
Generated from:
messageActionSuggestedPostRefund#69f916f8 flags:# payer_initiated:flags.0?true = MessageActionFields
payer_initiated: boolTrait Implementations
Sourceimpl Clone for MessageActionSuggestedPostRefund
impl Clone for MessageActionSuggestedPostRefund
Sourcefn clone(&self) -> MessageActionSuggestedPostRefund
fn clone(&self) -> MessageActionSuggestedPostRefund
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionSuggestedPostRefund
impl Deserializable for MessageActionSuggestedPostRefund
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionSuggestedPostRefund> for MessageAction
impl From<MessageActionSuggestedPostRefund> for MessageAction
Sourcefn from(x: MessageActionSuggestedPostRefund) -> Self
fn from(x: MessageActionSuggestedPostRefund) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionSuggestedPostRefund
impl Identifiable for MessageActionSuggestedPostRefund
Sourceconst CONSTRUCTOR_ID: u32 = 0x69f916f8
const CONSTRUCTOR_ID: u32 = 0x69f916f8
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionSuggestedPostRefund
impl PartialEq for MessageActionSuggestedPostRefund
Sourcefn eq(&self, other: &MessageActionSuggestedPostRefund) -> bool
fn eq(&self, other: &MessageActionSuggestedPostRefund) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionSuggestedPostRefund
impl TryFrom<MessageAction> for MessageActionSuggestedPostRefund
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionSuggestedPostRefund