pub struct MessageActionWebViewDataSent {
pub text: String,
}Expand description
Generated from:
messageActionWebViewDataSent#b4c38cb5 text:string = MessageActionFields
text: StringTrait Implementations
Sourceimpl Clone for MessageActionWebViewDataSent
impl Clone for MessageActionWebViewDataSent
Sourcefn clone(&self) -> MessageActionWebViewDataSent
fn clone(&self) -> MessageActionWebViewDataSent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageActionWebViewDataSent
impl Debug for MessageActionWebViewDataSent
Sourceimpl Deserializable for MessageActionWebViewDataSent
impl Deserializable for MessageActionWebViewDataSent
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionWebViewDataSent> for MessageAction
impl From<MessageActionWebViewDataSent> for MessageAction
Sourcefn from(x: MessageActionWebViewDataSent) -> Self
fn from(x: MessageActionWebViewDataSent) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionWebViewDataSent
impl Identifiable for MessageActionWebViewDataSent
Sourceconst CONSTRUCTOR_ID: u32 = 0xb4c38cb5
const CONSTRUCTOR_ID: u32 = 0xb4c38cb5
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionWebViewDataSent
impl PartialEq for MessageActionWebViewDataSent
Sourcefn eq(&self, other: &MessageActionWebViewDataSent) -> bool
fn eq(&self, other: &MessageActionWebViewDataSent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionWebViewDataSent
impl TryFrom<MessageAction> for MessageActionWebViewDataSent
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionWebViewDataSent