pub struct MessageActionWebViewDataSentMe {
pub text: String,
pub data: String,
}Expand description
messageActionWebViewDataSentMe
Generated from:
messageActionWebViewDataSentMe#47dd8079 text:string data:string = MessageActionFields
text: Stringdata: StringTrait Implementations
Sourceimpl Clone for MessageActionWebViewDataSentMe
impl Clone for MessageActionWebViewDataSentMe
Sourcefn clone(&self) -> MessageActionWebViewDataSentMe
fn clone(&self) -> MessageActionWebViewDataSentMe
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for MessageActionWebViewDataSentMe
impl Deserializable for MessageActionWebViewDataSentMe
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<MessageActionWebViewDataSentMe> for MessageAction
impl From<MessageActionWebViewDataSentMe> for MessageAction
Sourcefn from(x: MessageActionWebViewDataSentMe) -> Self
fn from(x: MessageActionWebViewDataSentMe) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for MessageActionWebViewDataSentMe
impl Identifiable for MessageActionWebViewDataSentMe
Sourceconst CONSTRUCTOR_ID: u32 = 0x47dd8079
const CONSTRUCTOR_ID: u32 = 0x47dd8079
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for MessageActionWebViewDataSentMe
impl PartialEq for MessageActionWebViewDataSentMe
Sourcefn eq(&self, other: &MessageActionWebViewDataSentMe) -> bool
fn eq(&self, other: &MessageActionWebViewDataSentMe) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<MessageAction> for MessageActionWebViewDataSentMe
impl TryFrom<MessageAction> for MessageActionWebViewDataSentMe
Sourcetype Error = MessageAction
type Error = MessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for MessageActionWebViewDataSentMe