pub struct PostInteractionCountersMessage {
pub msg_id: i32,
pub views: i32,
pub forwards: i32,
pub reactions: i32,
}Expand description
postInteractionCountersMessage
Generated from:
postInteractionCountersMessage#e7058e7f msg_id:int views:int forwards:int reactions:int = PostInteractionCountersFields
msg_id: i32views: i32forwards: i32reactions: i32Trait Implementations
Sourceimpl Clone for PostInteractionCountersMessage
impl Clone for PostInteractionCountersMessage
Sourcefn clone(&self) -> PostInteractionCountersMessage
fn clone(&self) -> PostInteractionCountersMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for PostInteractionCountersMessage
impl Deserializable for PostInteractionCountersMessage
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<PostInteractionCountersMessage> for PostInteractionCounters
impl From<PostInteractionCountersMessage> for PostInteractionCounters
Sourcefn from(x: PostInteractionCountersMessage) -> Self
fn from(x: PostInteractionCountersMessage) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for PostInteractionCountersMessage
impl Identifiable for PostInteractionCountersMessage
Sourceconst CONSTRUCTOR_ID: u32 = 0xe7058e7f
const CONSTRUCTOR_ID: u32 = 0xe7058e7f
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for PostInteractionCountersMessage
impl PartialEq for PostInteractionCountersMessage
Sourcefn eq(&self, other: &PostInteractionCountersMessage) -> bool
fn eq(&self, other: &PostInteractionCountersMessage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<PostInteractionCounters> for PostInteractionCountersMessage
impl TryFrom<PostInteractionCounters> for PostInteractionCountersMessage
Sourcetype Error = PostInteractionCounters
type Error = PostInteractionCounters
The type returned in the event of a conversion error.
impl StructuralPartialEq for PostInteractionCountersMessage