pub struct PostInteractionCountersStory {
pub story_id: i32,
pub views: i32,
pub forwards: i32,
pub reactions: i32,
}Expand description
Generated from:
postInteractionCountersStory#8a480e27 story_id:int views:int forwards:int reactions:int = PostInteractionCountersFields
story_id: i32views: i32forwards: i32reactions: i32Trait Implementations
Sourceimpl Clone for PostInteractionCountersStory
impl Clone for PostInteractionCountersStory
Sourcefn clone(&self) -> PostInteractionCountersStory
fn clone(&self) -> PostInteractionCountersStory
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PostInteractionCountersStory
impl Debug for PostInteractionCountersStory
Sourceimpl Deserializable for PostInteractionCountersStory
impl Deserializable for PostInteractionCountersStory
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<PostInteractionCountersStory> for PostInteractionCounters
impl From<PostInteractionCountersStory> for PostInteractionCounters
Sourcefn from(x: PostInteractionCountersStory) -> Self
fn from(x: PostInteractionCountersStory) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for PostInteractionCountersStory
impl Identifiable for PostInteractionCountersStory
Sourceconst CONSTRUCTOR_ID: u32 = 0x8a480e27
const CONSTRUCTOR_ID: u32 = 0x8a480e27
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for PostInteractionCountersStory
impl PartialEq for PostInteractionCountersStory
Sourcefn eq(&self, other: &PostInteractionCountersStory) -> bool
fn eq(&self, other: &PostInteractionCountersStory) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<PostInteractionCounters> for PostInteractionCountersStory
impl TryFrom<PostInteractionCounters> for PostInteractionCountersStory
Sourcetype Error = PostInteractionCounters
type Error = PostInteractionCounters
The type returned in the event of a conversion error.
impl StructuralPartialEq for PostInteractionCountersStory