pub struct PrivacyValueAllowChatParticipants {
pub chats: Vec<i64>,
}Expand description
privacyValueAllowChatParticipants
Generated from:
privacyValueAllowChatParticipants#6b134e8e chats:Vector<long> = PrivacyRuleFields
chats: Vec<i64>Trait Implementations
Sourceimpl Clone for PrivacyValueAllowChatParticipants
impl Clone for PrivacyValueAllowChatParticipants
Sourcefn clone(&self) -> PrivacyValueAllowChatParticipants
fn clone(&self) -> PrivacyValueAllowChatParticipants
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for PrivacyValueAllowChatParticipants
impl Deserializable for PrivacyValueAllowChatParticipants
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<PrivacyValueAllowChatParticipants> for PrivacyRule
impl From<PrivacyValueAllowChatParticipants> for PrivacyRule
Sourcefn from(x: PrivacyValueAllowChatParticipants) -> Self
fn from(x: PrivacyValueAllowChatParticipants) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for PrivacyValueAllowChatParticipants
impl Identifiable for PrivacyValueAllowChatParticipants
Sourceconst CONSTRUCTOR_ID: u32 = 0x6b134e8e
const CONSTRUCTOR_ID: u32 = 0x6b134e8e
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for PrivacyValueAllowChatParticipants
impl PartialEq for PrivacyValueAllowChatParticipants
Sourcefn eq(&self, other: &PrivacyValueAllowChatParticipants) -> bool
fn eq(&self, other: &PrivacyValueAllowChatParticipants) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<PrivacyRule> for PrivacyValueAllowChatParticipants
impl TryFrom<PrivacyRule> for PrivacyValueAllowChatParticipants
Sourcetype Error = PrivacyRule
type Error = PrivacyRule
The type returned in the event of a conversion error.
impl StructuralPartialEq for PrivacyValueAllowChatParticipants