pub struct PrivacyValueDisallowChatParticipants {
pub chats: Vec<i64>,
}Expand description
privacyValueDisallowChatParticipants
Generated from:
privacyValueDisallowChatParticipants#41c87565 chats:Vector<long> = PrivacyRuleFields
chats: Vec<i64>Trait Implementations
Sourceimpl Clone for PrivacyValueDisallowChatParticipants
impl Clone for PrivacyValueDisallowChatParticipants
Sourcefn clone(&self) -> PrivacyValueDisallowChatParticipants
fn clone(&self) -> PrivacyValueDisallowChatParticipants
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for PrivacyValueDisallowChatParticipants
impl Deserializable for PrivacyValueDisallowChatParticipants
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<PrivacyValueDisallowChatParticipants> for PrivacyRule
impl From<PrivacyValueDisallowChatParticipants> for PrivacyRule
Sourcefn from(x: PrivacyValueDisallowChatParticipants) -> Self
fn from(x: PrivacyValueDisallowChatParticipants) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for PrivacyValueDisallowChatParticipants
impl Identifiable for PrivacyValueDisallowChatParticipants
Sourceconst CONSTRUCTOR_ID: u32 = 0x41c87565
const CONSTRUCTOR_ID: u32 = 0x41c87565
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for PrivacyValueDisallowChatParticipants
impl PartialEq for PrivacyValueDisallowChatParticipants
Sourcefn eq(&self, other: &PrivacyValueDisallowChatParticipants) -> bool
fn eq(&self, other: &PrivacyValueDisallowChatParticipants) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<PrivacyRule> for PrivacyValueDisallowChatParticipants
impl TryFrom<PrivacyRule> for PrivacyValueDisallowChatParticipants
Sourcetype Error = PrivacyRule
type Error = PrivacyRule
The type returned in the event of a conversion error.
impl StructuralPartialEq for PrivacyValueDisallowChatParticipants