pub struct SecureValueErrorTranslationFile {
pub type: SecureValueType,
pub file_hash: Vec<u8>,
pub text: String,
}Expand description
secureValueErrorTranslationFile
Generated from:
secureValueErrorTranslationFile#a1144770 type:SecureValueType file_hash:bytes text:string = SecureValueErrorFields
type: SecureValueTypefile_hash: Vec<u8>text: StringTrait Implementations
Sourceimpl Clone for SecureValueErrorTranslationFile
impl Clone for SecureValueErrorTranslationFile
Sourcefn clone(&self) -> SecureValueErrorTranslationFile
fn clone(&self) -> SecureValueErrorTranslationFile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for SecureValueErrorTranslationFile
impl Deserializable for SecureValueErrorTranslationFile
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<SecureValueErrorTranslationFile> for SecureValueError
impl From<SecureValueErrorTranslationFile> for SecureValueError
Sourcefn from(x: SecureValueErrorTranslationFile) -> Self
fn from(x: SecureValueErrorTranslationFile) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for SecureValueErrorTranslationFile
impl Identifiable for SecureValueErrorTranslationFile
Sourceconst CONSTRUCTOR_ID: u32 = 0xa1144770
const CONSTRUCTOR_ID: u32 = 0xa1144770
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for SecureValueErrorTranslationFile
impl PartialEq for SecureValueErrorTranslationFile
Sourcefn eq(&self, other: &SecureValueErrorTranslationFile) -> bool
fn eq(&self, other: &SecureValueErrorTranslationFile) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<SecureValueError> for SecureValueErrorTranslationFile
impl TryFrom<SecureValueError> for SecureValueErrorTranslationFile
Sourcetype Error = SecureValueError
type Error = SecureValueError
The type returned in the event of a conversion error.
impl StructuralPartialEq for SecureValueErrorTranslationFile