pub struct SecureValueErrorTranslationFiles {
pub type: SecureValueType,
pub file_hash: Vec<Vec<u8>>,
pub text: String,
}Expand description
secureValueErrorTranslationFiles
Generated from:
secureValueErrorTranslationFiles#34636dd8 type:SecureValueType file_hash:Vector<bytes> text:string = SecureValueErrorFields
type: SecureValueTypefile_hash: Vec<Vec<u8>>text: StringTrait Implementations
Sourceimpl Clone for SecureValueErrorTranslationFiles
impl Clone for SecureValueErrorTranslationFiles
Sourcefn clone(&self) -> SecureValueErrorTranslationFiles
fn clone(&self) -> SecureValueErrorTranslationFiles
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for SecureValueErrorTranslationFiles
impl Deserializable for SecureValueErrorTranslationFiles
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<SecureValueErrorTranslationFiles> for SecureValueError
impl From<SecureValueErrorTranslationFiles> for SecureValueError
Sourcefn from(x: SecureValueErrorTranslationFiles) -> Self
fn from(x: SecureValueErrorTranslationFiles) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for SecureValueErrorTranslationFiles
impl Identifiable for SecureValueErrorTranslationFiles
Sourceconst CONSTRUCTOR_ID: u32 = 0x34636dd8
const CONSTRUCTOR_ID: u32 = 0x34636dd8
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for SecureValueErrorTranslationFiles
impl PartialEq for SecureValueErrorTranslationFiles
Sourcefn eq(&self, other: &SecureValueErrorTranslationFiles) -> bool
fn eq(&self, other: &SecureValueErrorTranslationFiles) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<SecureValueError> for SecureValueErrorTranslationFiles
impl TryFrom<SecureValueError> for SecureValueErrorTranslationFiles
Sourcetype Error = SecureValueError
type Error = SecureValueError
The type returned in the event of a conversion error.
impl StructuralPartialEq for SecureValueErrorTranslationFiles