pub struct SendMessageEmojiInteractionSeen {
pub emoticon: String,
}Expand description
sendMessageEmojiInteractionSeen
Generated from:
sendMessageEmojiInteractionSeen#b665902e emoticon:string = SendMessageActionFields
emoticon: StringTrait Implementations
Sourceimpl Clone for SendMessageEmojiInteractionSeen
impl Clone for SendMessageEmojiInteractionSeen
Sourcefn clone(&self) -> SendMessageEmojiInteractionSeen
fn clone(&self) -> SendMessageEmojiInteractionSeen
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for SendMessageEmojiInteractionSeen
impl Deserializable for SendMessageEmojiInteractionSeen
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<SendMessageEmojiInteractionSeen> for SendMessageAction
impl From<SendMessageEmojiInteractionSeen> for SendMessageAction
Sourcefn from(x: SendMessageEmojiInteractionSeen) -> Self
fn from(x: SendMessageEmojiInteractionSeen) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for SendMessageEmojiInteractionSeen
impl Identifiable for SendMessageEmojiInteractionSeen
Sourceconst CONSTRUCTOR_ID: u32 = 0xb665902e
const CONSTRUCTOR_ID: u32 = 0xb665902e
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for SendMessageEmojiInteractionSeen
impl PartialEq for SendMessageEmojiInteractionSeen
Sourcefn eq(&self, other: &SendMessageEmojiInteractionSeen) -> bool
fn eq(&self, other: &SendMessageEmojiInteractionSeen) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<SendMessageAction> for SendMessageEmojiInteractionSeen
impl TryFrom<SendMessageAction> for SendMessageEmojiInteractionSeen
Sourcetype Error = SendMessageAction
type Error = SendMessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for SendMessageEmojiInteractionSeen