pub struct SendMessageUploadPhotoAction {
pub progress: i32,
}Expand description
Generated from:
sendMessageUploadPhotoAction#d1d34a26 progress:int = SendMessageActionFields
progress: i32Trait Implementations
Sourceimpl Clone for SendMessageUploadPhotoAction
impl Clone for SendMessageUploadPhotoAction
Sourcefn clone(&self) -> SendMessageUploadPhotoAction
fn clone(&self) -> SendMessageUploadPhotoAction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendMessageUploadPhotoAction
impl Debug for SendMessageUploadPhotoAction
Sourceimpl Deserializable for SendMessageUploadPhotoAction
impl Deserializable for SendMessageUploadPhotoAction
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<SendMessageUploadPhotoAction> for SendMessageAction
impl From<SendMessageUploadPhotoAction> for SendMessageAction
Sourcefn from(x: SendMessageUploadPhotoAction) -> Self
fn from(x: SendMessageUploadPhotoAction) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for SendMessageUploadPhotoAction
impl Identifiable for SendMessageUploadPhotoAction
Sourceconst CONSTRUCTOR_ID: u32 = 0xd1d34a26
const CONSTRUCTOR_ID: u32 = 0xd1d34a26
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for SendMessageUploadPhotoAction
impl PartialEq for SendMessageUploadPhotoAction
Sourcefn eq(&self, other: &SendMessageUploadPhotoAction) -> bool
fn eq(&self, other: &SendMessageUploadPhotoAction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<SendMessageAction> for SendMessageUploadPhotoAction
impl TryFrom<SendMessageAction> for SendMessageUploadPhotoAction
Sourcetype Error = SendMessageAction
type Error = SendMessageAction
The type returned in the event of a conversion error.
impl StructuralPartialEq for SendMessageUploadPhotoAction