pub struct StarGiftAuctionStateFinished {
pub start_date: i32,
pub end_date: i32,
pub average_price: i64,
pub listed_count: Option<i32>,
pub fragment_listed_count: Option<i32>,
pub fragment_listed_url: Option<String>,
}Expand description
Generated from:
starGiftAuctionStateFinished#972dabbf flags:# start_date:int end_date:int average_price:long listed_count:flags.0?int fragment_listed_count:flags.1?int fragment_listed_url:flags.1?string = StarGiftAuctionStateFields
start_date: i32end_date: i32average_price: i64listed_count: Option<i32>fragment_listed_count: Option<i32>fragment_listed_url: Option<String>Trait Implementations
Sourceimpl Clone for StarGiftAuctionStateFinished
impl Clone for StarGiftAuctionStateFinished
Sourcefn clone(&self) -> StarGiftAuctionStateFinished
fn clone(&self) -> StarGiftAuctionStateFinished
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StarGiftAuctionStateFinished
impl Debug for StarGiftAuctionStateFinished
Sourceimpl Deserializable for StarGiftAuctionStateFinished
impl Deserializable for StarGiftAuctionStateFinished
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<StarGiftAuctionStateFinished> for StarGiftAuctionState
impl From<StarGiftAuctionStateFinished> for StarGiftAuctionState
Sourcefn from(x: StarGiftAuctionStateFinished) -> Self
fn from(x: StarGiftAuctionStateFinished) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for StarGiftAuctionStateFinished
impl Identifiable for StarGiftAuctionStateFinished
Sourceconst CONSTRUCTOR_ID: u32 = 0x972dabbf
const CONSTRUCTOR_ID: u32 = 0x972dabbf
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for StarGiftAuctionStateFinished
impl PartialEq for StarGiftAuctionStateFinished
Sourcefn eq(&self, other: &StarGiftAuctionStateFinished) -> bool
fn eq(&self, other: &StarGiftAuctionStateFinished) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<StarGiftAuctionState> for StarGiftAuctionStateFinished
impl TryFrom<StarGiftAuctionState> for StarGiftAuctionStateFinished
Sourcetype Error = StarGiftAuctionState
type Error = StarGiftAuctionState
The type returned in the event of a conversion error.
impl StructuralPartialEq for StarGiftAuctionStateFinished