pub struct WebPageAttributeStarGiftAuction {
pub gift: StarGift,
pub end_date: i32,
}Expand description
webPageAttributeStarGiftAuction
Generated from:
webPageAttributeStarGiftAuction#1c641c2 gift:StarGift end_date:int = WebPageAttributeFields
gift: StarGiftend_date: i32Trait Implementations
Sourceimpl Clone for WebPageAttributeStarGiftAuction
impl Clone for WebPageAttributeStarGiftAuction
Sourcefn clone(&self) -> WebPageAttributeStarGiftAuction
fn clone(&self) -> WebPageAttributeStarGiftAuction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for WebPageAttributeStarGiftAuction
impl Deserializable for WebPageAttributeStarGiftAuction
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<WebPageAttributeStarGiftAuction> for WebPageAttribute
impl From<WebPageAttributeStarGiftAuction> for WebPageAttribute
Sourcefn from(x: WebPageAttributeStarGiftAuction) -> Self
fn from(x: WebPageAttributeStarGiftAuction) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for WebPageAttributeStarGiftAuction
impl Identifiable for WebPageAttributeStarGiftAuction
Sourceconst CONSTRUCTOR_ID: u32 = 0x01c641c2
const CONSTRUCTOR_ID: u32 = 0x01c641c2
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for WebPageAttributeStarGiftAuction
impl PartialEq for WebPageAttributeStarGiftAuction
Sourcefn eq(&self, other: &WebPageAttributeStarGiftAuction) -> bool
fn eq(&self, other: &WebPageAttributeStarGiftAuction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<WebPageAttribute> for WebPageAttributeStarGiftAuction
impl TryFrom<WebPageAttribute> for WebPageAttributeStarGiftAuction
Sourcetype Error = WebPageAttribute
type Error = WebPageAttribute
The type returned in the event of a conversion error.
impl StructuralPartialEq for WebPageAttributeStarGiftAuction