pub struct WebPageAttributeStarGiftCollection {
pub icons: Vec<Document>,
}Expand description
webPageAttributeStarGiftCollection
Generated from:
webPageAttributeStarGiftCollection#31cad303 icons:Vector<Document> = WebPageAttributeFields
icons: Vec<Document>Trait Implementations
Sourceimpl Clone for WebPageAttributeStarGiftCollection
impl Clone for WebPageAttributeStarGiftCollection
Sourcefn clone(&self) -> WebPageAttributeStarGiftCollection
fn clone(&self) -> WebPageAttributeStarGiftCollection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Deserializable for WebPageAttributeStarGiftCollection
impl Deserializable for WebPageAttributeStarGiftCollection
Sourcefn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
fn deserialize(buf: Buffer<'_, '_>) -> Result<Self>
Read
Self from buf, advancing its position.Sourcefn from_bytes(bytes: &[u8]) -> Result<Self>
fn from_bytes(bytes: &[u8]) -> Result<Self>
Convenience: deserialize from a byte slice.
Sourceimpl From<WebPageAttributeStarGiftCollection> for WebPageAttribute
impl From<WebPageAttributeStarGiftCollection> for WebPageAttribute
Sourcefn from(x: WebPageAttributeStarGiftCollection) -> Self
fn from(x: WebPageAttributeStarGiftCollection) -> Self
Converts to this type from the input type.
Sourceimpl Identifiable for WebPageAttributeStarGiftCollection
impl Identifiable for WebPageAttributeStarGiftCollection
Sourceconst CONSTRUCTOR_ID: u32 = 0x31cad303
const CONSTRUCTOR_ID: u32 = 0x31cad303
The constructor ID as specified in the TL schema.
Sourceimpl PartialEq for WebPageAttributeStarGiftCollection
impl PartialEq for WebPageAttributeStarGiftCollection
Sourcefn eq(&self, other: &WebPageAttributeStarGiftCollection) -> bool
fn eq(&self, other: &WebPageAttributeStarGiftCollection) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<WebPageAttribute> for WebPageAttributeStarGiftCollection
impl TryFrom<WebPageAttribute> for WebPageAttributeStarGiftCollection
Sourcetype Error = WebPageAttribute
type Error = WebPageAttribute
The type returned in the event of a conversion error.
impl StructuralPartialEq for WebPageAttributeStarGiftCollection